@@ -1,11 +1,11 @@
 #
-# Copyright 2013-2014 Ghent University
+# Copyright 2013-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -27,34 +27,27 @@
 Easyconfig constants module that provides all constants that can
 be used within an Easyconfig file.
 
-@author: Stijn De Weirdt (Ghent University)
-@author: Kenneth Hoste (Ghent University)
+:author: Stijn De Weirdt (Ghent University)
+:author: Kenneth Hoste (Ghent University)
 """
+import os
 import platform
 from vsc.utils import fancylogger
 
 from easybuild.tools.systemtools import get_shared_lib_ext, get_os_name, get_os_type, get_os_version
 
+
 _log = fancylogger.getLogger('easyconfig.constants', fname=False)
 
+
+EXTERNAL_MODULE_MARKER = 'EXTERNAL_MODULE'
+
 # constants that can be used in easyconfig
 EASYCONFIG_CONSTANTS = {
-    'SYS_PYTHON_VERSION': (platform.python_version(), "System Python version (platform.python_version())"),
+    'EXTERNAL_MODULE': (EXTERNAL_MODULE_MARKER, "External module marker"),
+    'HOME': (os.path.expanduser('~'), "Home directory ($HOME)"),
     'OS_TYPE': (get_os_type(), "System type (e.g. 'Linux' or 'Darwin')"),
     'OS_NAME': (get_os_name(), "System name (e.g. 'fedora' or 'RHEL')"),
     'OS_VERSION': (get_os_version(), "System version"),
+    'SYS_PYTHON_VERSION': (platform.python_version(), "System Python version (platform.python_version())"),
 }
-
-
-def constant_documentation():
-    """Generate the easyconfig constant documentation"""
-    indent_l0 = " " * 2
-    indent_l1 = indent_l0 + " " * 2
-    doc = []
-
-    doc.append("Constants that can be used in easyconfigs")
-    for cst, (val, descr) in EASYCONFIG_CONSTANTS.items():
-        doc.append('%s%s: %s (%s)' % (indent_l1, cst, val, descr))
-
-    return "\n".join(doc)
-
