@@ -1,11 +1,11 @@
 # #
-# Copyright 2013-2014 Ghent University
+# Copyright 2013-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -26,20 +26,23 @@
 """
 The main easyconfig format class
 
-@author: Stijn De Weirdt (Ghent University)
-@author: Kenneth Hoste (Ghent University)
+:author: Stijn De Weirdt (Ghent University)
+:author: Kenneth Hoste (Ghent University)
 """
 import copy
 import re
 from vsc.utils import fancylogger
-from vsc.utils.missing import get_subclasses, any
+from vsc.utils.missing import get_subclasses
 
 from easybuild.framework.easyconfig.format.version import EasyVersion, OrderedVersionOperators
 from easybuild.framework.easyconfig.format.version import ToolchainVersionOperator, VersionOperator
 from easybuild.framework.easyconfig.format.convert import Dependency
+from easybuild.tools.build_log import EasyBuildError
 from easybuild.tools.configobj import Section
 
 
+INDENT_4SPACES = ' ' * 4
+
 # format is mandatory major.minor
 FORMAT_VERSION_KEYWORD = "EASYCONFIGFORMAT"
 FORMAT_VERSION_TEMPLATE = "%(major)s.%(minor)s"
@@ -47,6 +50,30 @@ FORMAT_VERSION_HEADER_TEMPLATE = "# %s %s\n" % (FORMAT_VERSION_KEYWORD, FORMAT_V
 FORMAT_VERSION_REGEXP = re.compile(r'^#\s+%s\s*(?P<major>\d+)\.(?P<minor>\d+)\s*$' % FORMAT_VERSION_KEYWORD, re.M)
 FORMAT_DEFAULT_VERSION = EasyVersion('1.0')
 
+DEPENDENCY_PARAMETERS = ['builddependencies', 'dependencies', 'hiddendependencies']
+
+# values for these keys will not be templated in dump()
+EXCLUDED_KEYS_REPLACE_TEMPLATES = ['description', 'easyblock', 'homepage', 'name', 'toolchain', 'version'] \
+                                  + DEPENDENCY_PARAMETERS
+
+# ordered groups of keys to obtain a nice looking easyconfig file
+GROUPED_PARAMS = [
+    ['easyblock'],
+    ['name', 'version', 'versionprefix', 'versionsuffix'],
+    ['homepage', 'description'],
+    ['toolchain', 'toolchainopts'],
+    ['sources', 'source_urls'],
+    ['patches'],
+    DEPENDENCY_PARAMETERS,
+    ['osdependencies'],
+    ['preconfigopts', 'configopts'],
+    ['prebuildopts', 'buildopts'],
+    ['preinstallopts', 'installopts'],
+    ['parallel', 'maxparallel'],
+]
+LAST_PARAMS = ['sanity_check_paths', 'moduleclass']
+
+
 _log = fancylogger.getLogger('easyconfig.format.format', fname=False)
 
 
@@ -59,7 +86,7 @@ def get_format_version(txt):
             maj_min = res.groupdict()
             format_version = EasyVersion(FORMAT_VERSION_TEMPLATE % maj_min)
         except (KeyError, TypeError), err:
-            _log.error("Failed to get version from match %s: %s" % (res.groups(), err))
+            raise EasyBuildError("Failed to get version from match %s: %s", res.groups(), err)
     return format_version
 
 
@@ -112,7 +139,7 @@ class Squashed(object):
     def add_toolchain(self, squashed):
         """
         Add squashed instance from a toolchain section
-        @param squashed: a Squashed instance
+        :param squashed: a Squashed instance
         """
         # TODO unify with add_version, make one .add()
         # data from toolchain
@@ -123,8 +150,8 @@ class Squashed(object):
     def add_version(self, section, squashed):
         """
         Add squashed instance from version section
-        @param section: the version section versionoperator instance
-        @param squashed: a Squashed instance
+        :param section: the version section versionoperator instance
+        :param squashed: a Squashed instance
         """
         # TODO unify with add_toolchain, make one .add()
         # don't update res_sections
@@ -186,7 +213,7 @@ class EBConfigObj(object):
     def __init__(self, configobj=None):
         """
         Initialise EBConfigObj instance
-        @param configobj: ConfigObj instance
+        :param configobj: ConfigObj instance
         """
         self.log = fancylogger.getLogger(self.__class__.__name__, fname=False)
 
@@ -212,8 +239,8 @@ class EBConfigObj(object):
 
         Returns a dict of (nested) Sections
 
-        @param toparse: a Section (or ConfigObj) instance, basically a dict of (unparsed) sections
-        @param current: the current NestedDict 
+        :param toparse: a Section (or ConfigObj) instance, basically a dict of (unparsed) sections
+        :param current: the current NestedDict 
         """
         # note: configobj already converts comma-separated strings in lists
         #
@@ -242,13 +269,13 @@ class EBConfigObj(object):
                     new_value = []
                     for dep_name, dep_val in value.items():
                         if isinstance(dep_val, Section):
-                            self.log.error("Unsupported nested section '%s' found in dependencies section" % dep_name)
+                            raise EasyBuildError("Unsupported nested section '%s' in dependencies section", dep_name)
                         else:
                             # FIXME: parse the dependency specification for version, toolchain, suffix, etc.
                             dep = Dependency(dep_val, name=dep_name)
                             if dep.name() is None or dep.version() is None:
-                                tmpl = "Failed to find name/version in parsed dependency: %s (dict: %s)"
-                                self.log.error(tmpl % (dep, dict(dep)))
+                                raise EasyBuildError("Failed to find name/version in parsed dependency: %s (dict: %s)",
+                                                     dep, dict(dep))
                             new_value.append(dep)
 
                     tmpl = 'Converted dependency section %s to %s, passed it to parent section (or default)'
@@ -268,7 +295,7 @@ class EBConfigObj(object):
                         else:
                             self.log.debug("Not a %s section marker" % marker_type.__name__)
                     if not new_key:
-                        self.log.error("Unsupported section marker '%s'" % key)
+                        raise EasyBuildError("Unsupported section marker '%s'", key)
 
                     # parse value as a section, recursively
                     new_value = self.parse_sections(value, current.get_nested_dict())
@@ -296,10 +323,10 @@ class EBConfigObj(object):
                     # remove possible surrounding whitespace (some people add space after comma)
                     new_value = [value_type(x.strip()) for x in value]
                     if False in [x.is_valid() for x in new_value]:
-                        self.log.error("Failed to parse '%s' as list of %s" % (value, value_type.__name__))
+                        raise EasyBuildError("Failed to parse '%s' as list of %s", value, value_type.__name__)
                 else:
-                    tup = (key, value, type(value))
-                    self.log.error('Bug: supported but unknown key %s with non-string value: %s, type %s' % tup)
+                    raise EasyBuildError('Bug: supported but unknown key %s with non-string value: %s, type %s',
+                                         key, value, type(value))
 
                 self.log.debug("Converted value '%s' for key '%s' into new value '%s'" % (value, key, new_value))
                 current[key] = new_value
@@ -311,7 +338,7 @@ class EBConfigObj(object):
         Parse configobj using using recursive parse_sections. 
         Then split off the default and supported sections. 
 
-        @param configobj: ConfigObj instance
+        :param configobj: ConfigObj instance
         """
         # keep reference to original (in case it's needed/wanted)
         self.configobj = configobj
@@ -334,7 +361,7 @@ class EBConfigObj(object):
         self.supported = self.sections.pop(self.SECTION_MARKER_SUPPORTED)
         for key, value in self.supported.items():
             if not key in self.VERSION_OPERATOR_VALUE_TYPES:
-                self.log.error('Unsupported key %s in %s section' % (key, self.SECTION_MARKER_SUPPORTED))
+                raise EasyBuildError('Unsupported key %s in %s section', key, self.SECTION_MARKER_SUPPORTED)
             self.sections['%s' % key] = value
 
         for key, supported_key, fn_name in [('version', 'versions', 'get_version_str'),
@@ -344,7 +371,7 @@ class EBConfigObj(object):
                 first = self.supported[supported_key][0]
                 f_val = getattr(first, fn_name)()
                 if f_val is None:
-                    self.log.error("First %s %s can't be used as default (%s returned None)" % (key, first, fn_name))
+                    raise EasyBuildError("First %s %s can't be used as default (%s returned None)", key, first, fn_name)
                 else:
                     self.log.debug('Using first %s (%s) as default %s' % (key, first, f_val))
                     self.default[key] = f_val
@@ -360,9 +387,9 @@ class EBConfigObj(object):
         Project the multidimensional easyconfig to single easyconfig
         It (tries to) detect conflicts in the easyconfig.
 
-        @param version: version to keep
-        @param tcname: toolchain name to keep
-        @param tcversion: toolchain version to keep
+        :param version: version to keep
+        :param tcname: toolchain name to keep
+        :param tcversion: toolchain version to keep
         """
         self.log.debug('Start squash with sections %s' % self.sections)
 
@@ -383,10 +410,10 @@ class EBConfigObj(object):
         """
         Project the multidimensional easyconfig (or subsection thereof) to single easyconfig
         Returns Squashed instance for the processed block.
-        @param vt_tuple: tuple with version (version to keep), tcname (toolchain name to keep) and 
+        :param vt_tuple: tuple with version (version to keep), tcname (toolchain name to keep) and 
                             tcversion (toolchain version to keep)
-        @param processed: easyconfig (Top)NestedDict
-        @param sanity: dictionary to keep track of section markers and detect conflicts 
+        :param processed: easyconfig (Top)NestedDict
+        :param sanity: dictionary to keep track of section markers and detect conflicts 
         """
         version, tcname, tcversion = vt_tuple
         res_sections = {}
@@ -423,11 +450,11 @@ class EBConfigObj(object):
         """
         Squash NestedDict instance, returns dict with already squashed data 
             from possible higher sections 
-        @param key: section key
-        @param nested_dict: the nested_dict instance
-        @param squashed: Squashed instance
-        @param sanity: the sanity dict
-        @param vt_tuple: version, tc_name, tc_version tuple
+        :param key: section key
+        :param nested_dict: the nested_dict instance
+        :param squashed: Squashed instance
+        :param sanity: the sanity dict
+        :param vt_tuple: version, tc_name, tc_version tuple
         """
         version, tcname, tcversion = vt_tuple
         res_sections = {}
@@ -438,8 +465,7 @@ class EBConfigObj(object):
             tc_overops.add(key)
 
             if key.test(tcname, tcversion):
-                tup = (tcname, tcversion, key)
-                self.log.debug("Found matching marker for specified toolchain '%s, %s': %s" % tup)
+                self.log.debug("Found matching marker for specified toolchain '%s, %s': %s", tcname, tcversion, key)
                 # TODO remove when unifying add_toolchina with .add()
                 tmp_squashed = self._squash(vt_tuple, nested_dict, sanity)
                 res_sections.update(tmp_squashed.result)
@@ -456,7 +482,7 @@ class EBConfigObj(object):
             else:
                 self.log.debug('Found non-matching version marker %s. Ignoring this (nested) section.' % key)
         else:
-            self.log.error("Unhandled section marker '%s' (type '%s')" % (key, type(key)))
+            raise EasyBuildError("Unhandled section marker '%s' (type '%s')", key, type(key))
 
         return res_sections
 
@@ -464,11 +490,11 @@ class EBConfigObj(object):
         """
         Squash VERSION_OPERATOR_VALUE_TYPES value 
             return None or new Squashed instance 
-        @param key: section key
-        @param nested_dict: the nested_dict instance
-        @param squashed: Squashed instance
-        @param sanity: the sanity dict
-        @param vt_tuple: version, tc_name, tc_version tuple
+        :param key: section key
+        :param nested_dict: the nested_dict instance
+        :param squashed: Squashed instance
+        :param sanity: the sanity dict
+        :param vt_tuple: version, tc_name, tc_version tuple
         """
         version, tcname, tcversion = vt_tuple
         if key == 'toolchains':
@@ -479,8 +505,8 @@ class EBConfigObj(object):
             tmp_tc_oversops = {}  # temporary, only for conflict checking
             for tcversop in value:
                 tc_overops = tmp_tc_oversops.setdefault(tcversop.tc_name, OrderedVersionOperators())
-                tup = (tcversop, tc_overops, tcname, tcversion)
-                self.log.debug('Add tcversop %s to tc_overops %s tcname %s tcversion %s' % tup)
+                self.log.debug("Add tcversop %s to tc_overops %s tcname %s tcversion %s",
+                               tcversop, tc_overops, tcname, tcversion)
                 tc_overops.add(tcversop)  # test non-conflicting list
                 if tcversop.test(tcname, tcversion):
                     matching_toolchains.append(tcversop)
@@ -507,7 +533,7 @@ class EBConfigObj(object):
                 self.log.debug('No matching versions, removing the whole current key %s' % key)
                 return Squashed()
         else:
-            self.log.error('Unexpected VERSION_OPERATOR_VALUE_TYPES key %s value %s' % (key, value))
+            raise EasyBuildError('Unexpected VERSION_OPERATOR_VALUE_TYPES key %s value %s', key, value)
 
         return None
 
@@ -520,11 +546,11 @@ class EBConfigObj(object):
                 version = self.default['version']
                 self.log.debug("No version specified, using default %s" % version)
             else:
-                self.log.error("No version specified, no default found.")
+                raise EasyBuildError("No version specified, no default found.")
         elif version in versions:
             self.log.debug("Version '%s' is supported in easyconfig." % version)
         else:
-            self.log.error("Version '%s' not supported in easyconfig (only %s)" % (version, versions))
+            raise EasyBuildError("Version '%s' not supported in easyconfig (only %s)", version, versions)
 
         tcnames = [tc.tc_name for tc in self.supported['toolchains']]
         if tcname is None:
@@ -532,11 +558,11 @@ class EBConfigObj(object):
                 tcname = self.default['toolchain']['name']
                 self.log.debug("No toolchain name specified, using default %s" % tcname)
             else:
-                self.log.error("No toolchain name specified, no default found.")
+                raise EasyBuildError("No toolchain name specified, no default found.")
         elif tcname in tcnames:
             self.log.debug("Toolchain '%s' is supported in easyconfig." % tcname)
         else:
-            self.log.error("Toolchain '%s' not supported in easyconfig (only %s)" % (tcname, tcnames))
+            raise EasyBuildError("Toolchain '%s' not supported in easyconfig (only %s)", tcname, tcnames)
 
         tcs = [tc for tc in self.supported['toolchains'] if tc.tc_name == tcname]
         if tcversion is None:
@@ -544,17 +570,16 @@ class EBConfigObj(object):
                 tcversion = self.default['toolchain']['version']
                 self.log.debug("No toolchain version specified, using default %s" % tcversion)
             else:
-                self.log.error("No toolchain version specified, no default found.")
+                raise EasyBuildError("No toolchain version specified, no default found.")
         elif any([tc.test(tcname, tcversion) for tc in tcs]):
             self.log.debug("Toolchain '%s' version '%s' is supported in easyconfig" % (tcname, tcversion))
         else:
-            tup = (tcname, tcversion, tcs)
-            self.log.error("Toolchain '%s' version '%s' not supported in easyconfig (only %s)" % tup)
+            raise EasyBuildError("Toolchain '%s' version '%s' not supported in easyconfig (only %s)",
+                                 tcname, tcversion, tcs)
 
-        tup = (version, tcname, tcversion)
-        self.log.debug('version %s, tcversion %s, tcname %s' % tup)
+        self.log.debug('version %s, tcversion %s, tcname %s', version, tcname, tcversion)
 
-        return tup
+        return (version, tcname, tcversion)
 
     def get_specs_for(self, version=None, tcname=None, tcversion=None):
         """
@@ -578,9 +603,10 @@ class EasyConfigFormat(object):
         self.log = fancylogger.getLogger(self.__class__.__name__, fname=False)
 
         if not len(self.VERSION) == len(FORMAT_VERSION_TEMPLATE.split('.')):
-            self.log.error('Invalid version number %s (incorrect length)' % self.VERSION)
+            raise EasyBuildError('Invalid version number %s (incorrect length)', self.VERSION)
 
         self.rawtext = None  # text version of the easyconfig
+        self.comments = {}  # comments in easyconfig file
         self.header = None  # easyconfig header (e.g., format version, license, ...)
         self.docstring = None  # easyconfig docstring (e.g., author, maintainer, ...)
 
@@ -603,10 +629,14 @@ class EasyConfigFormat(object):
         """Parse the txt according to this format. This is highly version specific"""
         raise NotImplementedError
 
-    def dump(self):
+    def dump(self, ecfg, default_values, templ_const, templ_val):
         """Dump easyconfig according to this format. This is higly version specific"""
         raise NotImplementedError
 
+    def extract_comments(self, rawtxt):
+        """Extract comments from raw content."""
+        raise NotImplementedError
+
 
 def get_format_version_classes(version=None):
     """Return the (usable) subclasses from EasyConfigFormat that have a matching version."""
