@@ -1,11 +1,11 @@
 #
-# Copyright 2013-2014 Ghent University
+# Copyright 2013-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -27,13 +27,14 @@
 Easyconfig templates module that provides templating that can
 be used within an Easyconfig file.
 
-@author: Stijn De Weirdt (Ghent University)
-@author: Fotis Georgatos (Uni.Lu, NTUA)
+:author: Stijn De Weirdt (Ghent University)
+:author: Fotis Georgatos (Uni.Lu, NTUA)
 """
-
+import re
 from vsc.utils import fancylogger
 from distutils.version import LooseVersion
 
+from easybuild.tools.build_log import EasyBuildError
 from easybuild.tools.systemtools import get_shared_lib_ext
 
 
@@ -41,15 +42,16 @@ _log = fancylogger.getLogger('easyconfig.templates', fname=False)
 
 # derived from easyconfig, but not from ._config directly
 TEMPLATE_NAMES_EASYCONFIG = [
+    ('nameletter', "First letter of software name"),
     ('toolchain_name', "Toolchain name"),
     ('toolchain_version', "Toolchain version"),
     ('version_major_minor', "Major.Minor version"),
     ('version_major', "Major version"),
     ('version_minor', "Minor version"),
-    ('nameletter', "First letter of software name"),
 ]
 # derived from EasyConfig._config
 TEMPLATE_NAMES_CONFIG = [
+    'github_account',
     'name',
     'version',
     'versionsuffix',
@@ -66,6 +68,14 @@ TEMPLATE_NAMES_EASYBLOCK_RUN_STEP = [
     ('installdir', "Installation directory"),
     ('builddir', "Build directory"),
 ]
+# software names for which to define <pref>ver and <pref>shortver templates
+TEMPLATE_SOFTWARE_VERSIONS = [
+    # software name, prefix for *ver and *shortver
+    ('Java', 'java'),
+    ('Perl', 'perl'),
+    ('Python', 'py'),
+    ('R', 'r'),
+]
 # constant templates that can be used in easyconfigs
 TEMPLATE_CONSTANTS = [
     # source url constants
@@ -79,7 +89,9 @@ TEMPLATE_CONSTANTS = [
      'CRAN (contrib) source url'),
     ('FTPGNOME_SOURCE', 'http://ftp.gnome.org/pub/GNOME/sources/%(namelower)s/%(version_major_minor)s',
      'http download for gnome ftp server'),
-    ('GNU_SAVANNAH_SOURCE', 'http://download.savannah.gnu.org/releases/%(namelower)s',
+    ('GITHUB_SOURCE', 'https://github.com/%(github_account)s/%(name)s/archive',
+     'GitHub source URL (requires github_account easyconfig parameter to be specified)'),
+    ('GNU_SAVANNAH_SOURCE', 'http://download-mirror.savannah.gnu.org/releases/%(namelower)s',
      'download.savannah.gnu.org source url'),
     ('GNU_SOURCE', 'http://ftpmirror.gnu.org/%(namelower)s',
      'gnu.org source url'),
@@ -87,9 +99,9 @@ TEMPLATE_CONSTANTS = [
      'googlecode.com source url'),
     ('LAUNCHPAD_SOURCE', 'https://launchpad.net/%(namelower)s/%(version_major_minor)s.x/%(version)s/+download/',
      'launchpad.net source url'),
-    ('PYPI_SOURCE', 'http://pypi.python.org/packages/source/%(nameletter)s/%(name)s',
+    ('PYPI_SOURCE', 'https://pypi.python.org/packages/source/%(nameletter)s/%(name)s',
      'pypi source url'),  # e.g., Cython, Sphinx
-    ('PYPI_LOWER_SOURCE', 'http://pypi.python.org/packages/source/%(nameletterlower)s/%(namelower)s',
+    ('PYPI_LOWER_SOURCE', 'https://pypi.python.org/packages/source/%(nameletterlower)s/%(namelower)s',
      'pypi source url (lowercase name)'),  # e.g., Greenlet, PyZMQ
     ('R_SOURCE', 'http://cran.r-project.org/src/base/R-%(version_major)s',
      'cran.r-project.org (base) source url'),
@@ -113,7 +125,7 @@ TEMPLATE_CONSTANTS = [
     ('SHLIB_EXT', get_shared_lib_ext(), 'extension for shared libraries'),
 ]
 
-extensions = ['tar.gz', 'tar.xz', 'tar.bz2', 'tgz', 'txz', 'tbz2', 'tb2', 'gtgz', 'zip', 'tar', 'xz']
+extensions = ['tar.gz', 'tar.xz', 'tar.bz2', 'tgz', 'txz', 'tbz2', 'tb2', 'gtgz', 'zip', 'tar', 'xz', 'tar.Z']
 for ext in extensions:
     suffix = ext.replace('.', '_').upper()
     TEMPLATE_CONSTANTS += [
@@ -124,6 +136,7 @@ for ext in extensions:
 # TODO derived config templates
 # versionmajor, versionminor, versionmajorminor (eg '.'.join(version.split('.')[:2])) )
 
+
 def template_constant_dict(config, ignore=None, skip_lower=True):
     """Create a dict for templating the values in the easyconfigs.
         - config is a dict with the structure of EasyConfig._config
@@ -132,7 +145,6 @@ def template_constant_dict(config, ignore=None, skip_lower=True):
     # ignore
     if ignore is None:
         ignore = []
-
     # make dict
     template_values = {}
 
@@ -142,8 +154,13 @@ def template_constant_dict(config, ignore=None, skip_lower=True):
     for name in TEMPLATE_NAMES_EASYCONFIG:
         if name in ignore:
             continue
+
+        # check if this template name is already handled
+        if template_values.get(name[0]) is not None:
+            continue
+
         if name[0].startswith('toolchain_'):
-            tc = config.get('toolchain')[0]
+            tc = config.get('toolchain')
             if tc is not None:
                 template_values['toolchain_name'] = tc.get('name', None)
                 template_values['toolchain_version'] = tc.get('version', None)
@@ -152,40 +169,56 @@ def template_constant_dict(config, ignore=None, skip_lower=True):
 
         elif name[0].startswith('version_'):
             # parse major and minor version numbers
-            version = config['version'][0]
+            version = config['version']
             if version is not None:
 
                 _log.debug("version found in easyconfig is %s", version)
-                version = LooseVersion(version).version
+                version = version.split('.')
                 try:
-                    major = str(version[0])
+                    major = version[0]
                     template_values['version_major'] = major
-                    minor = str(version[1])
+                    minor = version[1]
                     template_values['version_minor'] = minor
-                    template_values['version_major_minor'] = ".".join([major, minor])
+                    template_values['version_major_minor'] = '.'.join([major, minor])
                 except IndexError:
                     # if there is no minor version, skip it
                     pass
                 # only go through this once
                 ignore.extend(['version_major', 'version_minor', 'version_major_minor'])
+
         elif name[0].endswith('letter'):
             # parse first letters
             if name[0].startswith('name'):
-                softname = config['name'][0]
+                softname = config['name']
                 if softname is not None:
                     template_values['nameletter'] = softname[0]
         else:
-            _log.error("Undefined name %s from TEMPLATE_NAMES_EASYCONFIG" % name)
+            raise EasyBuildError("Undefined name %s from TEMPLATE_NAMES_EASYCONFIG", name)
 
-    # step 2: add remaining from config
+    # step 2: define *ver and *shortver templates
+    for name, pref in TEMPLATE_SOFTWARE_VERSIONS:
+        for dep in config.get('dependencies', []):
+            if isinstance(dep, dict):
+                dep_name, dep_version = dep['name'], dep['version']
+            elif isinstance(dep, (list, tuple)):
+                dep_name, dep_version = dep[0], dep[1]
+            else:
+                raise EasyBuildError("Unexpected type for dependency: %s", dep)
+
+            if isinstance(dep_name, basestring) and dep_name.lower() == name.lower():
+                template_values['%sver' % pref] = dep_version
+                template_values['%sshortver' % pref] = '.'.join(dep_version.split('.')[:2])
+                break
+
+    # step 3: add remaining from config
     for name in TEMPLATE_NAMES_CONFIG:
         if name in ignore:
             continue
         if name in config:
-            template_values[name] = config[name][0]
-            _log.debug('name: %s, config: %s', name, config[name][0])
+            template_values[name] = config[name]
+            _log.debug('name: %s, config: %s', name, config[name])
 
-    # step 3. make lower variants if not skip_lower
+    # step 4. make lower variants if not skip_lower
     if not skip_lower:
         for name in TEMPLATE_NAMES_LOWER:
             if name in ignore:
@@ -194,7 +227,7 @@ def template_constant_dict(config, ignore=None, skip_lower=True):
             if t_v is None:
                 continue
             try:
-                template_values[TEMPLATE_NAMES_LOWER_TEMPLATE % {'name':name}] = t_v.lower()
+                template_values[TEMPLATE_NAMES_LOWER_TEMPLATE % {'name': name}] = t_v.lower()
             except:
                 _log.debug("_getitem_string: can't get .lower() for name %s value %s (type %s)" %
                            (name, t_v, type(t_v)))
@@ -202,6 +235,31 @@ def template_constant_dict(config, ignore=None, skip_lower=True):
     return template_values
 
 
+def to_template_str(value, templ_const, templ_val):
+    """
+    Insert template values where possible
+        - value is a string
+        - templ_const is a dictionary of template strings (constants)
+        - templ_val is an ordered dictionary of template strings specific for this easyconfig file
+    """
+    old_value = None
+    while value != old_value:
+        old_value = value
+        # check for constant values
+        for tval, tname in templ_const.items():
+            if tval in value:
+                value = re.sub(r'(^|\W)' + re.escape(tval) + r'(\W|$)', r'\1' + tname + r'\2', value)
+
+        for tval, tname in templ_val.items():
+            # only replace full words with templates: word to replace should be at the beginning of a line
+            # or be preceded by a non-alphanumeric (\W). It should end at the end of a line or be succeeded
+            # by another non-alphanumeric.
+            if tval in value:
+                value = re.sub(r'(^|\W)' + re.escape(tval) + r'(\W|$)', r'\1%(' + tname + r')s\2', value)
+
+    return value
+
+
 def template_documentation():
     """Generate the templating documentation"""
     # This has to reflect the methods/steps used in easyconfig _generate_template_values
@@ -212,23 +270,29 @@ def template_documentation():
     # step 1: add TEMPLATE_NAMES_EASYCONFIG
     doc.append('Template names/values derived from easyconfig instance')
     for name in TEMPLATE_NAMES_EASYCONFIG:
-        doc.append("%s%s: %s" % (indent_l1, name[0], name[1]))
+        doc.append("%s%%(%s)s: %s" % (indent_l1, name[0], name[1]))
 
-    # step 2: add remaining self._config
+    # step 2: add *ver/*shortver templates for software listed in TEMPLATE_SOFTWARE_VERSIONS
+    doc.append("Template names/values for (short) software versions")
+    for name, pref in TEMPLATE_SOFTWARE_VERSIONS:
+        doc.append("%s%%(%sshortver)s: short version for %s (<major>.<minor>)" % (indent_l1, pref, name))
+        doc.append("%s%%(%sver)s: full version for %s" % (indent_l1, pref, name))
+
+    # step 3: add remaining self._config
     doc.append('Template names/values as set in easyconfig')
     for name in TEMPLATE_NAMES_CONFIG:
-        doc.append("%s%s" % (indent_l1, name))
+        doc.append("%s%%(%s)s" % (indent_l1, name))
 
-    # step 3. make lower variants
+    # step 4. make lower variants
     doc.append('Lowercase values of template values')
     for name in TEMPLATE_NAMES_LOWER:
-        doc.append("%s%s: lower case of value of %s" % (indent_l1, TEMPLATE_NAMES_LOWER_TEMPLATE % {'name': name}, name))
+        doc.append("%s%%(%s)s: lower case of value of %s" % (indent_l1, TEMPLATE_NAMES_LOWER_TEMPLATE % {'name': name}, name))
 
-    # step 4. self.template_values can/should be updated from outside easyconfig
+    # step 5. self.template_values can/should be updated from outside easyconfig
     # (eg the run_setp code in EasyBlock)
     doc.append('Template values set outside EasyBlock runstep')
     for name in TEMPLATE_NAMES_EASYBLOCK_RUN_STEP:
-        doc.append("%s%s: %s" % (indent_l1, name[0], name[1]))
+        doc.append("%s%%(%s)s: %s" % (indent_l1, name[0], name[1]))
 
     doc.append('Template constants that can be used in easyconfigs')
     for cst in TEMPLATE_CONSTANTS:
