@@ -1,11 +1,11 @@
 ##
-# Copyright 2009-2014 Ghent University
+# Copyright 2009-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -25,13 +25,13 @@
 """
 Easyconfig module that provides functionality for tweaking existing eaysconfig (.eb) files.
 
-@author: Stijn De Weirdt (Ghent University)
-@author: Dries Verdegem (Ghent University)
-@author: Kenneth Hoste (Ghent University)
-@author: Pieter De Baets (Ghent University)
-@author: Jens Timmerman (Ghent University)
-@author: Toon Willems (Ghent University)
-@author: Fotis Georgatos (Uni.Lu, NTUA)
+:author: Stijn De Weirdt (Ghent University)
+:author: Dries Verdegem (Ghent University)
+:author: Kenneth Hoste (Ghent University)
+:author: Pieter De Baets (Ghent University)
+:author: Jens Timmerman (Ghent University)
+:author: Toon Willems (Ghent University)
+:author: Fotis Georgatos (Uni.Lu, NTUA)
 """
 import copy
 import glob
@@ -42,7 +42,9 @@ from distutils.version import LooseVersion
 from vsc.utils import fancylogger
 from vsc.utils.missing import nub
 
+from easybuild.framework.easyconfig.default import get_easyconfig_parameter_default
 from easybuild.framework.easyconfig.easyconfig import EasyConfig, create_paths, process_easyconfig
+from easybuild.tools.build_log import EasyBuildError
 from easybuild.tools.filetools import read_file, write_file
 from easybuild.tools.module_naming_scheme.utilities import det_full_ec_version
 from easybuild.tools.robot import resolve_dependencies
@@ -68,13 +70,16 @@ def ec_filename_for(path):
     return fn
 
 
-def tweak(easyconfigs, build_specs, targetdir=None):
+def tweak(easyconfigs, build_specs, modtool, targetdirs=None):
     """Tweak list of easyconfigs according to provided build specifications."""
-
+    tweaked_ecs_path, tweaked_ecs_deps_path = None, None
+    if targetdirs is not None:
+        tweaked_ecs_path, tweaked_ecs_deps_path = targetdirs
     # make sure easyconfigs all feature the same toolchain (otherwise we *will* run into trouble)
     toolchains = nub(['%(name)s/%(version)s' % ec['ec']['toolchain'] for ec in easyconfigs])
     if len(toolchains) > 1:
-        _log.error("Multiple toolchains featured in easyconfigs, --try-X not supported in that case: %s" % toolchains)
+        raise EasyBuildError("Multiple toolchains featured in easyconfigs, --try-X not supported in that case: %s",
+                             toolchains)
 
     if 'name' in build_specs or 'version' in build_specs:
         # no recursion if software name/version build specification are included
@@ -86,33 +91,35 @@ def tweak(easyconfigs, build_specs, targetdir=None):
         # obtain full dependency graph for specified easyconfigs
         # easyconfigs will be ordered 'top-to-bottom': toolchain dependencies and toolchain first
         _log.debug("Applying build specifications recursively (no software name/version found): %s" % build_specs)
-        orig_ecs = resolve_dependencies(easyconfigs, retain_all_deps=True)
+        orig_ecs = resolve_dependencies(easyconfigs, modtool, retain_all_deps=True)
 
     # keep track of originally listed easyconfigs (via their path)
     listed_ec_paths = [ec['spec'] for ec in easyconfigs]
 
-    # obtain full dependency graph for specified easyconfigs
-    # easyconfigs will be ordered 'top-to-bottom': toolchain dependencies and toolchain first
-    orig_ecs = resolve_dependencies(easyconfigs, retain_all_deps=True)
-
     # determine toolchain based on last easyconfigs
-    toolchain = orig_ecs[-1]['ec']['toolchain']
-    _log.debug("Filtering using toolchain %s" % toolchain)
+    if orig_ecs:
+        toolchain = orig_ecs[-1]['ec']['toolchain']
+        _log.debug("Filtering using toolchain %s" % toolchain)
 
-    # filter easyconfigs unless a dummy toolchain is used: drop toolchain and toolchain dependencies
-    if toolchain['name'] != DUMMY_TOOLCHAIN_NAME:
-        while orig_ecs[0]['ec']['toolchain'] != toolchain:
-            orig_ecs = orig_ecs[1:]
+        # filter easyconfigs unless a dummy toolchain is used: drop toolchain and toolchain dependencies
+        if toolchain['name'] != DUMMY_TOOLCHAIN_NAME:
+            while orig_ecs[0]['ec']['toolchain'] != toolchain:
+                orig_ecs = orig_ecs[1:]
 
     # generate tweaked easyconfigs, and continue with those instead
     tweaked_easyconfigs = []
-    for orig_ec in orig_ecs:
-        new_ec_file = tweak_one(orig_ec['spec'], None, build_specs, targetdir=targetdir)
-        # only return tweaked easyconfigs for easyconfigs which were listed originally
-        # easyconfig files for dependencies are also generated but not included, and will be resolved via --robot
+    for orig_ec in orig_ecs:  
+        # Only return tweaked easyconfigs for easyconfigs which were listed originally on the command line (and use the
+        # prepended path so that they are found first).
+        # easyconfig files for dependencies are also generated but not included, they will be resolved via --robot
+        # either from existing easyconfigs or, if that fails, from easyconfigs in the appended path
         if orig_ec['spec'] in listed_ec_paths:
+            new_ec_file = tweak_one(orig_ec['spec'], None, build_specs, targetdir=tweaked_ecs_path)
             new_ecs = process_easyconfig(new_ec_file, build_specs=build_specs)
             tweaked_easyconfigs.extend(new_ecs)
+        else:
+            # Place all tweaked dependency easyconfigs in the directory appended to the robot path
+            new_ec_file = tweak_one(orig_ec['spec'], None, build_specs, targetdir=tweaked_ecs_deps_path)
 
     return tweaked_easyconfigs
 
@@ -140,10 +147,11 @@ def tweak_one(src_fn, target_fn, tweaks, targetdir=None):
     # determine new toolchain if it's being changed
     keys = tweaks.keys()
     if 'toolchain_name' in keys or 'toolchain_version' in keys:
+        # note: this assumes that the toolchain spec is single-line
         tc_regexp = re.compile(r"^\s*toolchain\s*=\s*(.*)$", re.M)
         res = tc_regexp.search(ectxt)
         if not res:
-            _log.error("No toolchain found in easyconfig file %s?" % src_fn)
+            raise EasyBuildError("No toolchain found in easyconfig file %s: %s", src_fn, ectxt)
 
         toolchain = eval(res.group(1))
         for key in ['name', 'version']:
@@ -162,11 +170,16 @@ def tweak_one(src_fn, target_fn, tweaks, targetdir=None):
 
     additions = []
 
+    # automagically clear out list of checksums if software version is being tweaked 
+    if 'version' in tweaks and 'checksums' not in tweaks:
+        tweaks['checksums'] = []
+        _log.warning("Tweaking version: checksums cleared, verification disabled.")
+
     # we need to treat list values seperately, i.e. we prepend to the current value (if any)
     for (key, val) in tweaks.items():
 
         if isinstance(val, list):
-            regexp = re.compile(r"^\s*%s\s*=\s*(.*)$" % key, re.M)
+            regexp = re.compile(r"^(?P<key>\s*%s)\s*=\s*(?P<val>\[(.|\n)*\])\s*$" % key, re.M)
             res = regexp.search(ectxt)
             if res:
                 fval = [x for x in val if x != '']  # filter out empty strings
@@ -174,49 +187,52 @@ def tweak_one(src_fn, target_fn, tweaks, targetdir=None):
                 # - input ending with comma (empty tail list element) => prepend
                 # - input starting with comma (empty head list element) => append
                 # - no empty head/tail list element => overwrite
-                if val[0] == '':
-                    newval = "%s + %s" % (res.group(1), fval)
+                if not val:
+                    newval = '[]'
+                    _log.debug("Clearing %s to empty list (was: %s)" % (key, res.group('val')))
+                elif val[0] == '':
+                    newval = "%s + %s" % (res.group('val'), fval)
                     _log.debug("Appending %s to %s" % (fval, key))
                 elif val[-1] == '':
-                    newval = "%s + %s" % (fval, res.group(1))
+                    newval = "%s + %s" % (fval, res.group('val'))
                     _log.debug("Prepending %s to %s" % (fval, key))
                 else:
                     newval = "%s" % fval
                     _log.debug("Overwriting %s with %s" % (key, fval))
-                ectxt = regexp.sub("%s = %s # tweaked by EasyBuild (was: %s)" % (key, newval, res.group(1)), ectxt)
+                ectxt = regexp.sub("%s = %s" % (res.group('key'), newval), ectxt)
                 _log.info("Tweaked %s list to '%s'" % (key, newval))
-            else:
-                additions.append("%s = %s # added by EasyBuild" % (key, val))
+            elif get_easyconfig_parameter_default(key) != val:
+                additions.append("%s = %s" % (key, val))
 
             tweaks.pop(key)
 
     # add parameters or replace existing ones
     for (key, val) in tweaks.items():
 
-        regexp = re.compile(r"^\s*%s\s*=\s*(.*)$" % key, re.M)
+        regexp = re.compile(r"^(?P<key>\s*%s)\s*=\s*(?P<val>.*)$" % key, re.M)
         _log.debug("Regexp pattern for replacing '%s': %s" % (key, regexp.pattern))
         res = regexp.search(ectxt)
         if res:
             # only tweak if the value is different
             diff = True
             try:
-                _log.debug("eval(%s): %s" % (res.group(1), eval(res.group(1))))
-                diff = not eval(res.group(1)) == val
+                _log.debug("eval(%s): %s" % (res.group('val'), eval(res.group('val'))))
+                diff = eval(res.group('val')) != val
             except (NameError, SyntaxError):
                 # if eval fails, just fall back to string comparison
-                _log.debug("eval failed for \"%s\", falling back to string comparison against \"%s\"..." % (res.group(1), val))
-                diff = not res.group(1) == val
+                _log.debug("eval failed for \"%s\", falling back to string comparison against \"%s\"...",
+                           res.group('val'), val)
+                diff = res.group('val') != val
 
             if diff:
-                ectxt = regexp.sub("%s = %s # tweaked by EasyBuild (was: %s)" % (key, quote_str(val), res.group(1)), ectxt)
+                ectxt = regexp.sub("%s = %s" % (res.group('key'), quote_str(val)), ectxt)
                 _log.info("Tweaked '%s' to '%s'" % (key, quote_str(val)))
-        else:
+        elif get_easyconfig_parameter_default(key) != val:
             additions.append("%s = %s" % (key, quote_str(val)))
 
     if additions:
-        _log.info("Adding additional parameters to tweaked easyconfig file: %s")
-        ectxt += "\n\n# added by EasyBuild as dictated by command line options\n"
-        ectxt += '\n'.join(additions) + '\n'
+        _log.info("Adding additional parameters to tweaked easyconfig file: %s" % additions)
+        ectxt = '\n'.join([ectxt] + additions)
 
     _log.debug("Contents of tweaked easyconfig file:\n%s" % ectxt)
 
@@ -237,7 +253,7 @@ def tweak_one(src_fn, target_fn, tweaks, targetdir=None):
             # get rid of temporary file
             os.remove(tmpfn)
         except OSError, err:
-            _log.error("Failed to determine suiting filename for tweaked easyconfig file: %s" % err)
+            raise EasyBuildError("Failed to determine suiting filename for tweaked easyconfig file: %s", err)
 
         if targetdir is None:
             targetdir = tempfile.gettempdir()
@@ -260,12 +276,12 @@ def pick_version(req_ver, avail_vers):
     This function returns both the version to be used, which is equal to the required version
     if it was specified, and the version picked that matches that closest.
 
-    @param req_ver: required version
-    @param avail_vers: list of available versions
+    :param req_ver: required version
+    :param avail_vers: list of available versions
     """
 
     if not avail_vers:
-        _log.error("Empty list of available versions passed.")
+        raise EasyBuildError("Empty list of available versions passed.")
 
     selected_ver = None
     if req_ver:
@@ -294,15 +310,15 @@ def find_matching_easyconfigs(name, installver, paths):
     """
     Find easyconfigs that match specified name/installversion in specified list of paths.
 
-    @param name: software name
-    @param installver: software install version (which includes version, toolchain, versionprefix/suffix, ...)
-    @param paths: list of paths to search easyconfigs in
+    :param name: software name
+    :param installver: software install version (which includes version, toolchain, versionprefix/suffix, ...)
+    :param paths: list of paths to search easyconfigs in
     """
     ec_files = []
     for path in paths:
         patterns = create_paths(path, name, installver)
         for pattern in patterns:
-            more_ec_files = filter(os.path.isfile, glob.glob(pattern))
+            more_ec_files = filter(os.path.isfile, sorted(glob.glob(pattern)))
             _log.debug("Including files that match glob pattern '%s': %s" % (pattern, more_ec_files))
             ec_files.extend(more_ec_files)
 
@@ -334,7 +350,7 @@ def select_or_generate_ec(fp, paths, specs):
 
     # ensure that at least name is specified
     if not specs.get('name'):
-        _log.error("Supplied 'specs' dictionary doesn't even contain a name of a software package?")
+        raise EasyBuildError("Supplied 'specs' dictionary doesn't even contain a name of a software package?")
     name = specs['name']
     handled_params = ['name']
 
@@ -362,7 +378,8 @@ def select_or_generate_ec(fp, paths, specs):
                 _log.debug("No template found at %s." % templ_file)
 
         if len(ec_files) == 0:
-            _log.error("No easyconfig files found for software %s, and no templates available. I'm all out of ideas." % name)
+            raise EasyBuildError("No easyconfig files found for software %s, and no templates available. "
+                                 "I'm all out of ideas.", name)
 
     ecs_and_files = [(EasyConfig(f, validate=False), f) for f in ec_files]
 
@@ -390,8 +407,8 @@ def select_or_generate_ec(fp, paths, specs):
         if EASYCONFIG_TEMPLATE in tcnames:
             _log.info("No easyconfig file for specified toolchain, but template is available.")
         else:
-            _log.error("No easyconfig file for %s with toolchain %s, " \
-                      "and no template available." % (name, specs['toolchain_name']))
+            raise EasyBuildError("No easyconfig file for %s with toolchain %s, and no template available.",
+                                 name, specs['toolchain_name'])
 
     tcname = specs.pop('toolchain_name', None)
     handled_params.append('toolchain_name')
@@ -414,7 +431,7 @@ def select_or_generate_ec(fp, paths, specs):
             else:
                 # if multiple toolchains are available, and none is specified, we quit
                 # we can't just pick one, how would we prefer one over the other?
-                _log.error("No toolchain name specified, and more than one available: %s." % tcnames)
+                raise EasyBuildError("No toolchain name specified, and more than one available: %s.", tcnames)
 
     _log.debug("Filtering easyconfigs based on toolchain name '%s'..." % selected_tcname)
     ecs_and_files = [x for x in ecs_and_files if x[0]['toolchain']['name'] == selected_tcname]
@@ -497,9 +514,7 @@ def select_or_generate_ec(fp, paths, specs):
             filter_ecs = True
         else:
             # otherwise, we fail, because we don't know how to pick between different fixes
-            _log.error("No %s specified, and can't pick from available %ses %s" % (param,
-                                                                                  param,
-                                                                                  vals))
+            raise EasyBuildError("No %s specified, and can't pick from available ones: %s", param, vals)
 
         if filter_ecs:
             _log.debug("Filtering easyconfigs based on %s '%s'..." % (param, selected_val))
@@ -515,7 +530,7 @@ def select_or_generate_ec(fp, paths, specs):
     cnt = len(ecs_and_files)
     if not cnt == 1:
         fs = [x[1] for x in ecs_and_files]
-        _log.error("Failed to select a single easyconfig from available ones, %s left: %s" % (cnt, fs))
+        raise EasyBuildError("Failed to select a single easyconfig from available ones, %s left: %s", cnt, fs)
     else:
         (selected_ec, selected_ec_file) = ecs_and_files[0]
 
@@ -524,7 +539,7 @@ def select_or_generate_ec(fp, paths, specs):
         for (key, val) in specs.items():
             if key in selected_ec._config:
                 # values must be equal to have a full match
-                if not selected_ec[key] == val:
+                if selected_ec[key] != val:
                     match = False
             else:
                 # if we encounter a key that is not set in the selected easyconfig, we don't have a full match
@@ -563,18 +578,18 @@ def obtain_ec_for(specs, paths, fp=None):
     Either select between available ones, or use the best suited available one
     to generate a new easyconfig file.
 
-    @param specs: list of available easyconfig files
-    @param paths: a list of paths where easyconfig files can be found
-    @param fp: the desired file name
+    :param specs: list of available easyconfig files
+    :param paths: a list of paths where easyconfig files can be found
+    :param fp: the desired file name
     """
 
     # ensure that at least name is specified
     if not specs.get('name'):
-        _log.error("Supplied 'specs' dictionary doesn't even contain a name of a software package?")
+        raise EasyBuildError("Supplied 'specs' dictionary doesn't even contain a name of a software package?")
 
     # collect paths to search in
     if not paths:
-        _log.error("No paths to look for easyconfig files, specify a path with --robot.")
+        raise EasyBuildError("No paths to look for easyconfig files, specify a path with --robot.")
 
     # select best easyconfig, or try to generate one that fits the requirements
     res = select_or_generate_ec(fp, paths, specs)
@@ -582,4 +597,4 @@ def obtain_ec_for(specs, paths, fp=None):
     if res:
         return res
     else:
-        _log.error("No easyconfig found for requested software, and also failed to generate one.")
+        raise EasyBuildError("No easyconfig found for requested software, and also failed to generate one.")
