@@ -1,11 +1,11 @@
 ##
-# Copyright 2012-2014 Ghent University
+# Copyright 2012-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -25,8 +25,8 @@
 """
 EasyBuild support for gompic compiler toolchain (includes GCC and OpenMPI and CUDA).
 
-@author: Kenneth Hoste (Ghent University)
-@author: Fotis Georgatos (Uni.Lu, NTUA)
+:author: Kenneth Hoste (Ghent University)
+:author: Fotis Georgatos (Uni.Lu, NTUA)
 """
 
 from easybuild.toolchains.gcccuda import GccCUDA
@@ -36,3 +36,4 @@ from easybuild.toolchains.mpi.openmpi import OpenMPI
 class Gompic(GccCUDA, OpenMPI):
     """Compiler toolchain with GCC+CUDA and OpenMPI."""
     NAME = 'gompic'
+    SUBTOOLCHAIN = GccCUDA.NAME
