@@ -1,11 +1,11 @@
 ##
-# Copyright 2012-2014 Ghent University
+# Copyright 2012-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -25,16 +25,17 @@
 """
 EasyBuild support for iompi compiler toolchain (includes Intel compilers (icc, ifort) and OpenMPI.
 
-@author: Stijn De Weirdt (Ghent University)
-@author: Kenneth Hoste (Ghent University)
+:author: Stijn De Weirdt (Ghent University)
+:author: Kenneth Hoste (Ghent University)
 """
 
-from easybuild.toolchains.compiler.inteliccifort import IntelIccIfort
+from easybuild.toolchains.iccifort import IccIfort
 from easybuild.toolchains.mpi.openmpi import OpenMPI
 
 
-class Iompi(IntelIccIfort, OpenMPI):
+class Iompi(IccIfort, OpenMPI):
     """
     Compiler toolchain with Intel compilers (icc/ifort) and OpenMPI.
     """
     NAME = 'iompi'
+    SUBTOOLCHAIN = IccIfort.NAME
