@@ -1,11 +1,11 @@
 ##
-# Copyright 2012-2014 Ghent University
+# Copyright 2012-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -25,22 +25,26 @@
 """
 Support for Intel MKL as toolchain linear algebra library.
 
-@author: Stijn De Weirdt (Ghent University)
-@author: Kenneth Hoste (Ghent University)
+:author: Stijn De Weirdt (Ghent University)
+:author: Kenneth Hoste (Ghent University)
 """
-
 from distutils.version import LooseVersion
 
-from easybuild.toolchains.compiler.inteliccifort import TC_CONSTANT_INTELCOMP
 from easybuild.toolchains.compiler.gcc import TC_CONSTANT_GCC
+from easybuild.toolchains.compiler.inteliccifort import TC_CONSTANT_INTELCOMP
+from easybuild.toolchains.compiler.pgi import TC_CONSTANT_PGI
 from easybuild.toolchains.mpi.intelmpi import TC_CONSTANT_INTELMPI
 from easybuild.toolchains.mpi.mpich import TC_CONSTANT_MPICH
 from easybuild.toolchains.mpi.mpich2 import TC_CONSTANT_MPICH2
 from easybuild.toolchains.mpi.mvapich2 import TC_CONSTANT_MVAPICH2
 from easybuild.toolchains.mpi.openmpi import TC_CONSTANT_OPENMPI
+from easybuild.tools.build_log import EasyBuildError
 from easybuild.tools.toolchain.linalg import LinAlg
 
 
+TC_CONSTANT_INTELMKL = 'IntelMKL'
+
+
 class IntelMKL(LinAlg):
     """Support for Intel MKL."""
 
@@ -55,9 +59,11 @@ class IntelMKL(LinAlg):
     BLAS_LIB_MT = ["mkl_%(interface)s%(lp64)s" , "mkl_%(interface_mt)s_thread", "mkl_core"]
     BLAS_LIB_GROUP = True
     BLAS_LIB_STATIC = True
+    BLAS_FAMILY = TC_CONSTANT_INTELMKL
 
     LAPACK_MODULE_NAME = ['imkl']
     LAPACK_IS_BLAS = True
+    LAPACK_FAMILY = TC_CONSTANT_INTELMKL
 
     BLACS_MODULE_NAME = ['imkl']
     BLACS_LIB = ["mkl_blacs%(mpi)s%(lp64)s"]
@@ -68,34 +74,60 @@ class IntelMKL(LinAlg):
     SCALAPACK_MODULE_NAME = ['imkl']
     SCALAPACK_LIB = ["mkl_scalapack%(lp64_sc)s"]
     SCALAPACK_LIB_MT = ["mkl_scalapack%(lp64_sc)s"]
-    SCALAPACK_LIB_MAP = {"lp64_sc":"_lp64"}
+    SCALAPACK_LIB_MAP = {'lp64_sc': '_lp64'}
     SCALAPACK_REQUIRES = ['LIBBLACS', 'LIBBLAS']
     SCALAPACK_LIB_GROUP = True
     SCALAPACK_LIB_STATIC = True
 
+    def __init__(self, *args, **kwargs):
+        """Toolchain constructor."""
+        class_constants = kwargs.setdefault('class_constants', [])
+        class_constants.extend(['BLAS_LIB_MAP', 'SCALAPACK_LIB', 'SCALAPACK_LIB_MT', 'SCALAPACK_LIB_MAP'])
+        super(IntelMKL, self).__init__(*args, **kwargs)
+
+    def set_variables(self):
+        """Set the variables"""
+
+        # for recent versions of Intel MKL, -ldl should be used for linking;
+        # the Intel MKL Link Advisor specifies to always do this,
+        # but it is only needed when statically linked with Intel MKL,
+        # and only strictly needed for some compilers (e.g. PGI)
+        mkl_version = self.get_software_version(self.BLAS_MODULE_NAME)[0]
+        if LooseVersion(mkl_version) >= LooseVersion('11') and self.COMPILER_FAMILY in [TC_CONSTANT_PGI]:
+            self.log.info("Adding -ldl as extra library when linking with Intel MKL libraries (for v11.x and newer)")
+            if self.LIB_EXTRA is None:
+                self.LIB_EXTRA = ['dl']
+            elif 'dl' not in self.LIB_EXTRA:
+                self.LIB_EXTRA.append('dl')
+
+        super(IntelMKL, self).set_variables()
+
     def _set_blas_variables(self):
         """Fix the map a bit"""
         interfacemap = {
             TC_CONSTANT_INTELCOMP: 'intel',
             TC_CONSTANT_GCC: 'gf',
+            # Taken from https://www.pgroup.com/support/link.htm#mkl
+            TC_CONSTANT_PGI: 'intel',
         }
         try:
             self.BLAS_LIB_MAP.update({
                 "interface": interfacemap[self.COMPILER_FAMILY],
             })
         except:
-            self.log.raiseException(("_set_blas_variables: interface unsupported combination"
-                                     " with MPI family %s") % self.COMPILER_FAMILY)
+            raise EasyBuildError("_set_blas_variables: interface unsupported combination with MPI family %s",
+                                 self.COMPILER_FAMILY)
 
         interfacemap_mt = {
             TC_CONSTANT_INTELCOMP: 'intel',
             TC_CONSTANT_GCC: 'gnu',
+            TC_CONSTANT_PGI: 'pgi',
         }
         try:
             self.BLAS_LIB_MAP.update({"interface_mt":interfacemap_mt[self.COMPILER_FAMILY]})
         except:
-            self.log.raiseException(("_set_blas_variables: interface_mt unsupported combination "
-                                     "with compiler family %s") % self.COMPILER_FAMILY)
+            raise EasyBuildError("_set_blas_variables: interface_mt unsupported combination with compiler family %s",
+                                 self.COMPILER_FAMILY)
 
 
         if self.options.get('32bit', None):
@@ -117,8 +149,8 @@ class IntelMKL(LinAlg):
             self.BLAS_INCLUDE_DIR = ['include']
         else:
             if self.options.get('32bit', None):
-                self.log.raiseException(("_set_blas_variables: 32-bit libraries not supported yet "
-                                        "for IMKL v%s (> v10.3)") % found_version)
+                raise EasyBuildError("_set_blas_variables: 32-bit libraries not supported yet for IMKL v%s (> v10.3)",
+                                     found_version)
             else:
                 self.BLAS_LIB_DIR = ['mkl/lib/intel64', 'compiler/lib/intel64' ]
 
@@ -140,8 +172,8 @@ class IntelMKL(LinAlg):
         try:
             self.BLACS_LIB_MAP.update({'mpi': mpimap[self.MPI_FAMILY]})
         except:
-            self.log.raiseException(("_set_blacs_variables: mpi unsupported combination with"
-                                     " MPI family %s") % self.MPI_FAMILY)
+            raise EasyBuildError("_set_blacs_variables: mpi unsupported combination with MPI family %s",
+                                 self.MPI_FAMILY)
 
         self.BLACS_LIB_DIR = self.BLAS_LIB_DIR
         self.BLACS_INCLUDE_DIR = self.BLAS_INCLUDE_DIR
@@ -166,4 +198,3 @@ class IntelMKL(LinAlg):
         self.SCALAPACK_INCLUDE_DIR = self.BLAS_INCLUDE_DIR
 
         super(IntelMKL, self)._set_scalapack_variables()
-
