@@ -1,11 +1,11 @@
 # #
-# Copyright 2014-2014 Ghent University
+# Copyright 2014-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -26,7 +26,7 @@
 """
 This module implements all supported formats and their converters 
 
-@author: Stijn De Weirdt (Ghent University)
+:author: Stijn De Weirdt (Ghent University)
 """
 import re
 
@@ -34,6 +34,9 @@ from vsc.utils import fancylogger
 from vsc.utils.missing import get_subclasses, nub
 from vsc.utils.wrapper import Wrapper
 
+from easybuild.tools.build_log import EasyBuildError
+
+
 _log = fancylogger.getLogger('tools.convert', fname=False)
 
 
@@ -56,17 +59,17 @@ class Convert(Wrapper):
         if isinstance(obj, basestring):
             self.data = self._from_string(obj)
         else:
-            self.log.error('unsupported type %s for %s: %s' % (type(obj), self.__class__.__name__, obj))
+            raise EasyBuildError("unsupported type %s for %s: %s", type(obj), self.__class__.__name__, obj)
         super(Convert, self).__init__(self.data)
 
     def _split_string(self, txt, sep=None, max=0):
         """Split using sep, return list with results.
-            @param sep: if not provided, self.SEPARATOR is tried
-            @param max: split in max+1 elements (default: 0 == no limit)
+            :param sep: if not provided, self.SEPARATOR is tried
+            :param max: split in max+1 elements (default: 0 == no limit)
         """
         if sep is None:
             if self.SEPARATOR is None:
-                self.log.error('No SEPARATOR set, also no separator passed')
+                raise EasyBuildError("No SEPARATOR set, also no separator passed")
             else:
                 sep = self.SEPARATOR
         return [x.strip() for x in re.split(r'' + sep, txt, maxsplit=max)]
@@ -221,4 +224,4 @@ def get_convert_class(class_name):
     if len(res) == 1:
         return res[0]
     else:
-        _log.error('More then one Convert subclass found for name %s: %s' % (class_name, res))
+        raise EasyBuildError("More than one Convert subclass found for name %s: %s", class_name, res)
