@@ -1,11 +1,11 @@
 ##
-# Copyright 2011-2014 Ghent University
+# Copyright 2011-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -25,16 +25,15 @@
 """
 Declares easybuild.tools.module_naming_scheme namespace, in an extendable way.
 
-@author: Jens Timmerman (Ghent University)
-@author: Kenneth Hoste (Ghent University)
+:author: Jens Timmerman (Ghent University)
+:author: Kenneth Hoste (Ghent University)
 """
-from pkgutil import extend_path
+import pkg_resources
 
 # required for backward compatibility
 from easybuild.tools.module_naming_scheme.mns import ModuleNamingScheme
 
-# we're not the only ones in this namespace
-__path__ = extend_path(__path__, __name__)  #@ReservedAssignment
+pkg_resources.declare_namespace(__name__)
 
 # suffix for devel module filename
 DEVEL_MODULE_SUFFIX = '-easybuild-devel'
