@@ -1,11 +1,11 @@
 ##
-# Copyright 2013-2014 Ghent University
+# Copyright 2013-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -25,14 +25,15 @@
 """
 Implementation of an example hierarchical module naming scheme.
 
-@author: Kenneth Hoste (Ghent University)
-@author: Markus Geimer (Forschungszentrum Juelich GmbH)
+:author: Kenneth Hoste (Ghent University)
+:author: Markus Geimer (Forschungszentrum Juelich GmbH)
 """
 
 import os
 import re
 from vsc.utils import fancylogger
 
+from easybuild.tools.build_log import EasyBuildError
 from easybuild.tools.module_naming_scheme import ModuleNamingScheme
 from easybuild.tools.module_naming_scheme.toolchain import det_toolchain_compilers, det_toolchain_mpi
 
@@ -46,9 +47,19 @@ MODULECLASS_MPI = 'mpi'
 
 # note: names in keys are ordered alphabetically
 COMP_NAME_VERSION_TEMPLATES = {
+    # required for use of iccifort toolchain
     'icc,ifort': ('intel', '%(icc)s'),
+    # required for use of ClangGCC toolchain
     'Clang,GCC': ('Clang-GCC', '%(Clang)s-%(GCC)s'),
+    # required for use of gcccuda toolchain, and for CUDA installed with GCC toolchain
     'CUDA,GCC': ('GCC-CUDA', '%(GCC)s-%(CUDA)s'),
+    # required for use of iccifortcuda toolchain
+    'CUDA,icc,ifort': ('intel-CUDA', '%(icc)s-%(CUDA)s'),
+    # required for CUDA installed with iccifort toolchain
+    # need to use 'intel' here because 'iccifort' toolchain maps to 'intel' (see above)
+    'CUDA,intel': ('intel-CUDA', '%(intel)s-%(CUDA)s'),
+    # required for use of xlcxlf toolchain
+    'xlc,xlf': ('xlcxlf', '%(xlc)s'),
 }
 
 
@@ -92,7 +103,7 @@ class HierarchicalMNS(ModuleNamingScheme):
             # no compiler in toolchain, dummy toolchain
             res = None
         elif len(tc_comps) == 1:
-            res = (tc_comps[0]['name'], tc_comps[0]['version'])
+            res = (tc_comps[0]['name'], self.det_full_version(tc_comps[0]))
         else:
             comp_versions = dict([(comp['name'], self.det_full_version(comp)) for comp in tc_comps])
             comp_names = comp_versions.keys()
@@ -102,9 +113,10 @@ class HierarchicalMNS(ModuleNamingScheme):
                 tc_comp_ver = tc_comp_ver_tmpl % comp_versions
                 # make sure that icc/ifort versions match
                 if tc_comp_name == 'intel' and comp_versions['icc'] != comp_versions['ifort']:
-                    self.log.error("Bumped into different versions for Intel compilers: %s" % comp_versions)
+                    raise EasyBuildError("Bumped into different versions for Intel compilers: %s", comp_versions)
             else:
-                self.log.error("Unknown set of toolchain compilers, module naming scheme needs work: %s" % comp_names)
+                raise EasyBuildError("Unknown set of toolchain compilers, module naming scheme needs work: %s",
+                                     comp_names)
             res = (tc_comp_name, tc_comp_ver)
         return res
 
@@ -115,13 +127,12 @@ class HierarchicalMNS(ModuleNamingScheme):
         Examples: Core, Compiler/GCC/4.8.3, MPI/GCC/4.8.3/OpenMPI/1.6.5
         """
         tc_comps = det_toolchain_compilers(ec)
-        tc_comp_info = self.det_toolchain_compilers_name_version(tc_comps)
         # determine prefix based on type of toolchain used
-        if tc_comp_info is None:
+        if tc_comps is None:
             # no compiler in toolchain, dummy toolchain => Core module
             subdir = CORE
         else:
-            tc_comp_name, tc_comp_ver = tc_comp_info
+            tc_comp_name, tc_comp_ver = self.det_toolchain_compilers_name_version(tc_comps)
             tc_mpi = det_toolchain_mpi(ec)
             if tc_mpi is None:
                 # compiler-only toolchain => Compiler/<compiler_name>/<compiler_version> namespace
@@ -133,6 +144,13 @@ class HierarchicalMNS(ModuleNamingScheme):
 
         return subdir
 
+    def det_module_symlink_paths(self, ec):
+        """
+        Determine list of paths in which symlinks to module files must be created.
+        """
+        # symlinks are not very useful in the context of a hierarchical MNS
+        return []
+
     def det_modpath_extensions(self, ec):
         """
         Determine module path extensions, if any.
@@ -142,8 +160,15 @@ class HierarchicalMNS(ModuleNamingScheme):
         tc_comps = det_toolchain_compilers(ec)
         tc_comp_info = self.det_toolchain_compilers_name_version(tc_comps)
 
+        # we consider the following to be compilers:
+        # * has 'compiler' specified as moduleclass
+        is_compiler = modclass == MODULECLASS_COMPILER
+        # * CUDA, but only when not installed with 'dummy' toolchain (i.e. one or more toolchain compilers found)
+        non_dummy_tc = tc_comps is not None
+        non_dummy_cuda = ec['name'] == 'CUDA' and non_dummy_tc
+
         paths = []
-        if modclass == MODULECLASS_COMPILER or ec['name'] in ['CUDA']:
+        if is_compiler or non_dummy_cuda:
             # obtain list of compilers based on that extend $MODULEPATH in some way other than <name>/<version>
             extend_comps = []
             # exclude GCC for which <name>/<version> is used as $MODULEPATH extension
@@ -154,29 +179,38 @@ class HierarchicalMNS(ModuleNamingScheme):
             comp_name_ver = None
             if ec['name'] in extend_comps:
                 for key in COMP_NAME_VERSION_TEMPLATES:
-                    if ec['name'] in key.split(','):
+                    comp_names = key.split(',')
+                    if ec['name'] in comp_names:
                         comp_name, comp_ver_tmpl = COMP_NAME_VERSION_TEMPLATES[key]
                         comp_versions = {ec['name']: self.det_full_version(ec)}
                         if ec['name'] == 'ifort':
                             # 'icc' key should be provided since it's the only one used in the template
                             comp_versions.update({'icc': self.det_full_version(ec)})
-                        if tc_comp_info is not None:
-                            # also provide toolchain version for non-dummy toolchains
-                            comp_versions.update({tc_comp_info[0]: tc_comp_info[1]})
 
-                        comp_name_ver = [comp_name, comp_ver_tmpl % comp_versions]
-                        break
+                        if non_dummy_tc:
+                            tc_comp_name, tc_comp_ver = tc_comp_info
+                            if tc_comp_name in comp_names:
+                                # also provide toolchain version for non-dummy toolchains
+                                comp_versions.update({tc_comp_name: tc_comp_ver})
+
+                        comp_ver_keys = re.findall(r'%\((\w+)\)s', comp_ver_tmpl)
+                        if all(comp_ver_key in comp_versions for comp_ver_key in comp_ver_keys):
+                            comp_name_ver = [comp_name, comp_ver_tmpl % comp_versions]
+                            break
             else:
                 comp_name_ver = [ec['name'], self.det_full_version(ec)]
 
+            if comp_name_ver is None:
+                raise EasyBuildError("Required compilers not available in toolchain %s for %s v%s",
+                                     ec['toolchain'], ec['name'], ec['version'])
+
             paths.append(os.path.join(COMPILER, *comp_name_ver))
 
         elif modclass == MODULECLASS_MPI:
             if tc_comp_info is None:
-                tup = (ec['toolchain'], ec['name'], ec['version'])
-                error_msg = ("No compiler available in toolchain %s used to install MPI library %s v%s, "
-                             "which is required by the active module naming scheme.") % tup
-                self.log.error(error_msg)
+                raise EasyBuildError("No compiler available in toolchain %s used to install MPI library %s v%s, "
+                                     "which is required by the active module naming scheme.",
+                                     ec['toolchain'], ec['name'], ec['version'])
             else:
                 tc_comp_name, tc_comp_ver = tc_comp_info
                 fullver = self.det_full_version(ec)
