@@ -1,11 +1,11 @@
 # #
-# Copyright 2009-2014 Ghent University
+# Copyright 2009-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -27,24 +27,27 @@ Repository tools
 
 Plain filesystem repository
 
-@author: Stijn De Weirdt (Ghent University)
-@author: Dries Verdegem (Ghent University)
-@author: Kenneth Hoste (Ghent University)
-@author: Pieter De Baets (Ghent University)
-@author: Jens Timmerman (Ghent University)
-@author: Toon Willems (Ghent University)
-@author: Ward Poelmans (Ghent University)
-@author: Fotis Georgatos (Uni.Lu, NTUA)
+:author: Stijn De Weirdt (Ghent University)
+:author: Dries Verdegem (Ghent University)
+:author: Kenneth Hoste (Ghent University)
+:author: Pieter De Baets (Ghent University)
+:author: Jens Timmerman (Ghent University)
+:author: Toon Willems (Ghent University)
+:author: Ward Poelmans (Ghent University)
+:author: Fotis Georgatos (Uni.Lu, NTUA)
 """
 import os
 import time
 
 from easybuild.framework.easyconfig.easyconfig import EasyConfig
+from easybuild.framework.easyconfig.format.one import EB_FORMAT_EXTENSION
+from easybuild.framework.easyconfig.format.yeb import YEB_FORMAT_EXTENSION, is_yeb_format
 from easybuild.framework.easyconfig.tools import stats_to_str
 from easybuild.tools.filetools import mkdir, read_file, write_file
 from easybuild.tools.repository.repository import Repository
 from easybuild.tools.version import VERBOSE_VERSION
 
+
 class FileRepository(Repository):
     """Class for file repositories."""
 
@@ -76,9 +79,18 @@ class FileRepository(Repository):
         # create directory for eb file
         full_path = os.path.join(self.wc, self.subdir, name)
         mkdir(full_path, parents=True)
+        yeb_format = is_yeb_format(cfg, None)
+
+        if yeb_format:
+            extension = YEB_FORMAT_EXTENSION
+            prefix = "buildstats: ["
+
+        else:
+            extension = EB_FORMAT_EXTENSION
+            prefix = "buildstats = ["
 
         # destination
-        dest = os.path.join(full_path, "%s-%s.eb" % (name, version))
+        dest = os.path.join(full_path, "%s-%s%s" % (name, version, extension))
 
         txt = "# Built with EasyBuild version %s on %s\n" % (VERBOSE_VERSION, time.strftime("%Y-%m-%d_%H-%M-%S"))
 
@@ -86,15 +98,18 @@ class FileRepository(Repository):
         txt += read_file(cfg)
 
         # append a line to the eb file so that we don't have git merge conflicts
-        if not previous:
-            statsprefix = "\n# Build statistics\nbuildstats = ["
-            statssuffix = "]\n"
+        statscomment = "\n# Build statistics\n"
+        statsprefix = prefix
+        statssuffix = "]\n"
+        if previous:
+            statstxt = statscomment + statsprefix + '\n'
+            for entry in previous + [stats]:
+                statstxt += stats_to_str(entry, isyeb=yeb_format) + ',\n'
+            statstxt += statssuffix
         else:
-            # statstemplate = "\nbuildstats.append(%s)\n"
-            statsprefix = "\nbuildstats.append("
-            statssuffix = ")\n"
+            statstxt = statscomment + statsprefix + stats_to_str(stats, isyeb=yeb_format) + statssuffix
 
-        txt += statsprefix + stats_to_str(stats) + statssuffix
+        txt += statstxt
         write_file(dest, txt)
 
         return dest
