@@ -1,11 +1,11 @@
 # #
-# Copyright 2009-2014 Ghent University
+# Copyright 2009-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -27,14 +27,14 @@ Repository tools
 
 Svn repository
 
-@author: Stijn De Weirdt (Ghent University)
-@author: Dries Verdegem (Ghent University)
-@author: Kenneth Hoste (Ghent University)
-@author: Pieter De Baets (Ghent University)
-@author: Jens Timmerman (Ghent University)
-@author: Toon Willems (Ghent University)
-@author: Ward Poelmans (Ghent University)
-@author: Fotis Georgatos (Uni.Lu, NTUA)
+:author: Stijn De Weirdt (Ghent University)
+:author: Dries Verdegem (Ghent University)
+:author: Kenneth Hoste (Ghent University)
+:author: Pieter De Baets (Ghent University)
+:author: Jens Timmerman (Ghent University)
+:author: Toon Willems (Ghent University)
+:author: Ward Poelmans (Ghent University)
+:author: Fotis Georgatos (Uni.Lu, NTUA)
 """
 import getpass
 import os
@@ -43,14 +43,17 @@ import tempfile
 import time
 from vsc.utils import fancylogger
 
+from easybuild.tools.build_log import EasyBuildError
 from easybuild.tools.filetools import rmtree2
 from easybuild.tools.repository.filerepo import FileRepository
+from easybuild.tools.utilities import only_if_module_is_available
+
 
 _log = fancylogger.getLogger('svnrepo', fname=False)
 
+
 # optional Python packages, these might be missing
 # failing imports are just ignored
-# a NameError should be catched where these are used
 
 # PySVN
 try:
@@ -58,7 +61,7 @@ try:
     from pysvn import ClientError  # IGNORE:E0611 pysvn fails to recognize ClientError is available
     HAVE_PYSVN = True
 except ImportError:
-    _log.debug('Failed to import pysvn module')
+    _log.debug("Failed to import pysvn module")
     HAVE_PYSVN = False
 
 
@@ -73,9 +76,10 @@ class SvnRepository(FileRepository):
 
     USABLE = HAVE_PYSVN
 
+    @only_if_module_is_available('pysvn', url='http://pysvn.tigris.org/')
     def __init__(self, *args):
         """
-        Set self.client to None. Real logic is in setupRepo and createWorkingCopy
+        Set self.client to None. Real logic is in setup_repo and create_working_copy
         """
         self.client = None
         FileRepository.__init__(self, *args)
@@ -85,11 +89,6 @@ class SvnRepository(FileRepository):
         Set up SVN repository.
         """
         self.repo = os.path.join(self.repo, self.subdir)
-        try:
-            pysvn.ClientError  # IGNORE:E0611 pysvn fails to recognize ClientError is available
-        except NameError, err:
-            self.log.exception("pysvn not available (%s). Make sure it is installed " % err +
-                               "properly. Run 'python -c \"import pysvn\"' to test.")
 
         # try to connect to the repository
         self.log.debug("Try to connect to repository %s" % self.repo)
@@ -97,13 +96,13 @@ class SvnRepository(FileRepository):
             self.client = pysvn.Client()
             self.client.exception_style = 0
         except ClientError:
-            self.log.exception("Svn Client initialization failed.")
+            raise EasyBuildError("Svn Client initialization failed.")
 
         try:
             if not self.client.is_url(self.repo):
-                self.log.error("Provided repository %s is not a valid svn url" % self.repo)
+                raise EasyBuildError("Provided repository %s is not a valid svn url", self.repo)
         except ClientError:
-            self.log.exception("Can't connect to svn repository %s" % self.repo)
+            raise EasyBuildError("Can't connect to svn repository %s", self.repo)
 
     def create_working_copy(self):
         """
@@ -116,16 +115,16 @@ class SvnRepository(FileRepository):
         try:
             self.client.info2(self.repo, recurse=False)
         except ClientError:
-            self.log.exception("Getting info from %s failed." % self.wc)
+            raise EasyBuildError("Getting info from %s failed.", self.wc)
 
         try:
             res = self.client.update(self.wc)
             self.log.debug("Updated to revision %s in %s" % (res, self.wc))
         except ClientError:
-            self.log.exception("Update in wc %s went wrong" % self.wc)
+            raise EasyBuildError("Update in wc %s went wrong", self.wc)
 
         if len(res) == 0:
-            self.log.error("Update returned empy list (working copy: %s)" % (self.wc))
+            raise EasyBuildError("Update returned empy list (working copy: %s)", self.wc)
 
         if res[0].number == -1:
             # revision number of update is -1
@@ -134,7 +133,7 @@ class SvnRepository(FileRepository):
                 res = self.client.checkout(self.repo, self.wc)
                 self.log.debug("Checked out revision %s in %s" % (res.number, self.wc))
             except ClientError, err:
-                self.log.exception("Checkout of path / in working copy %s went wrong: %s" % (self.wc, err))
+                raise EasyBuildError("Checkout of path / in working copy %s went wrong: %s", self.wc, err)
 
     def add_easyconfig(self, cfg, name, version, stats, append):
         """
@@ -154,13 +153,13 @@ class SvnRepository(FileRepository):
         """
         Commit working copy to SVN repository
         """
-        completemsg = "EasyBuild-commit from %s (time: %s, user: %s) \n%s" % (socket.gethostname(),
-                                                                              time.strftime("%Y-%m-%d_%H-%M-%S"),
-                                                                              getpass.getuser(), msg)
+        tup = (socket.gethostname(), time.strftime("%Y-%m-%d_%H-%M-%S"), getpass.getuser(), msg)
+        completemsg = "EasyBuild-commit from %s (time: %s, user: %s) \n%s" % tup
+
         try:
             self.client.checkin(self.wc, completemsg, recurse=True)
         except ClientError, err:
-            self.log.exception("Commit from working copy %s (msg: %s) failed: %s" % (self.wc, msg, err))
+            raise EasyBuildError("Commit from working copy %s (msg: %s) failed: %s", self.wc, msg, err)
 
     def cleanup(self):
         """
@@ -169,4 +168,4 @@ class SvnRepository(FileRepository):
         try:
             rmtree2(self.wc)
         except OSError, err:
-            self.log.exception("Can't remove working copy %s: %s" % (self.wc, err))
+            raise EasyBuildError("Can't remove working copy %s: %s", self.wc, err)
