@@ -1,11 +1,11 @@
 # #
-# Copyright 2012-2014 Ghent University
+# Copyright 2012-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -28,19 +28,17 @@ dependencies)
 
 Support for PBS is provided via the PbsJob class. If you want you could create other job classes and use them here.
 
-@author: Toon Willems (Ghent University)
-@author: Kenneth Hoste (Ghent University)
-@author: Stijn De Weirdt (Ghent University)
-@author: Ward Poelmans (Ghent University)
+:author: Toon Willems (Ghent University)
+:author: Kenneth Hoste (Ghent University)
+:author: Stijn De Weirdt (Ghent University)
+:author: Ward Poelmans (Ghent University)
 """
 import copy
 import os
-import re
 import sys
 from datetime import datetime
 from time import gmtime, strftime
 
-import easybuild.tools.config as config
 from easybuild.framework.easyblock import build_easyconfigs
 from easybuild.framework.easyconfig.tools import process_easyconfig
 from easybuild.framework.easyconfig.tools import skip_available
@@ -49,7 +47,6 @@ from easybuild.tools.config import build_option
 from easybuild.tools.filetools import find_easyconfigs, mkdir, read_file, write_file
 from easybuild.tools.github import create_gist, post_comment_in_issue
 from easybuild.tools.jenkins import aggregate_xml_in_dirs
-from easybuild.tools.modules import modules_tool
 from easybuild.tools.parallelbuild import build_easyconfigs_in_parallel
 from easybuild.tools.robot import resolve_dependencies
 from easybuild.tools.systemtools import get_system_info
@@ -60,11 +57,12 @@ from vsc.utils import fancylogger
 _log = fancylogger.getLogger('testing', fname=False)
 
 
-def regtest(easyconfig_paths, build_specs=None):
+def regtest(easyconfig_paths, modtool, build_specs=None):
     """
     Run regression test, using easyconfigs available in given path
-    @param easyconfig_paths: path of easyconfigs to run regtest on
-    @param build_specs: dictionary specifying build specifications (e.g. version, toolchain, ...)
+    :param easyconfig_paths: path of easyconfigs to run regtest on
+    :param modtool: ModulesTool instance to use
+    :param build_specs: dictionary specifying build specifications (e.g. version, toolchain, ...)
     """
 
     cur_dir = os.getcwd()
@@ -96,7 +94,7 @@ def regtest(easyconfig_paths, build_specs=None):
         for path in easyconfig_paths:
             ecfiles += find_easyconfigs(path, ignore_dirs=build_option('ignore_dirs'))
     else:
-        _log.error("No easyconfig paths specified.")
+        raise EasyBuildError("No easyconfig paths specified.")
 
     test_results = []
 
@@ -111,37 +109,21 @@ def regtest(easyconfig_paths, build_specs=None):
     # skip easyconfigs for which a module is already available, unless forced
     if not build_option('force'):
         _log.debug("Skipping easyconfigs from %s that already have a module available..." % easyconfigs)
-        easyconfigs = skip_available(easyconfigs)
+        easyconfigs = skip_available(easyconfigs, modtool)
         _log.debug("Retained easyconfigs after skipping: %s" % easyconfigs)
 
     if build_option('sequential'):
         return build_easyconfigs(easyconfigs, output_dir, test_results)
     else:
-        resolved = resolve_dependencies(easyconfigs, build_specs=build_specs)
+        resolved = resolve_dependencies(easyconfigs, modtool)
 
         cmd = "eb %(spec)s --regtest --sequential -ld --testoutput=%(output_dir)s"
         command = "unset TMPDIR && cd %s && %s; " % (cur_dir, cmd)
         # retry twice in case of failure, to avoid fluke errors
         command += "if [ $? -ne 0 ]; then %(cmd)s --force && %(cmd)s --force; fi" % {'cmd': cmd}
 
-        jobs = build_easyconfigs_in_parallel(command, resolved, output_dir=output_dir)
+        build_easyconfigs_in_parallel(command, resolved, output_dir=output_dir)
 
-        print "List of submitted jobs:"
-        for job in jobs:
-            print "%s: %s" % (job.name, job.jobid)
-        print "(%d jobs submitted)" % len(jobs)
-
-        # determine leaf nodes in dependency graph, and report them
-        all_deps = set()
-        for job in jobs:
-            all_deps = all_deps.union(job.deps)
-
-        leaf_nodes = []
-        for job in jobs:
-            if job.jobid not in all_deps:
-                leaf_nodes.append(str(job.jobid).split('.')[0])
-
-        _log.info("Job ids of leaf nodes in dep. graph: %s" % ','.join(leaf_nodes))
         _log.info("Submitted regression test as jobs, results in %s" % output_dir)
 
         return True  # success
@@ -156,12 +138,6 @@ def session_state():
     }
 
 
-def session_module_list(testing=False):
-    """Get list of loaded modules ('module list')."""
-    modtool = modules_tool(testing=testing)
-    return modtool.list()
-
-
 def create_test_report(msg, ecs_with_res, init_session_state, pr_nr=None, gist_log=False):
     """Create test report for easyconfigs PR, in Markdown format."""
     user = build_option('github_user')
@@ -279,8 +255,9 @@ def post_easyconfigs_pr_test_report(pr_nr, test_report, msg, init_session_state,
 
     # post comment to report test result
     system_info = init_session_state['system_info']
-    short_system_info = "%(os_type)s %(os_name)s %(os_version)s, %(cpu_model)s, Python %(pyver)s" % {
+    short_system_info = "%(hostname)s - %(os_type)s %(os_name)s %(os_version)s, %(cpu_model)s, Python %(pyver)s" % {
         'cpu_model': system_info['cpu_model'],
+        'hostname': system_info['hostname'],
         'os_name': system_info['os_name'],
         'os_type': system_info['os_type'],
         'os_version': system_info['os_version'],
@@ -303,11 +280,11 @@ def post_easyconfigs_pr_test_report(pr_nr, test_report, msg, init_session_state,
 def overall_test_report(ecs_with_res, orig_cnt, success, msg, init_session_state):
     """
     Upload/dump overall test report
-    @param ecs_with_res: processed easyconfigs with build result (success/failure)
-    @param orig_cnt: number of original easyconfig paths
-    @param success: boolean indicating whether all builds were successful
-    @param msg: message to be included in test report
-    @param init_session_state: initial session state info to include in test report
+    :param ecs_with_res: processed easyconfigs with build result (success/failure)
+    :param orig_cnt: number of original easyconfig paths
+    :param success: boolean indicating whether all builds were successful
+    :param msg: message to be included in test report
+    :param init_session_state: initial session state info to include in test report
     """
     dump_path = build_option('dump_test_report')
     pr_nr = build_option('from_pr')
