@@ -1,11 +1,11 @@
 ##
-# Copyright 2012-2014 Ghent University
+# Copyright 2012-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -25,8 +25,8 @@
 """
 Toolchain fft module, provides abstract class for FFT libraries.
 
-@author: Stijn De Weirdt (Ghent University)
-@author: Kenneth Hoste (Ghent University)
+:author: Stijn De Weirdt (Ghent University)
+:author: Kenneth Hoste (Ghent University)
 """
 
 from easybuild.tools.toolchain.toolchain import Toolchain
@@ -39,6 +39,7 @@ class Fft(Toolchain):
 
     FFT_MODULE_NAME = None
     FFT_LIB = None
+    FFT_LIB_MT = None
     FFT_LIB_GROUP = False
     FFT_LIB_STATIC = False
     FFT_LIB_DIR = ['lib']
@@ -55,7 +56,18 @@ class Fft(Toolchain):
         self.variables.add_begin_end_linkerflags(fft_libs, toggle_startstopgroup=self.FFT_LIB_GROUP,
                                                  toggle_staticdynamic=self.FFT_LIB_STATIC)
 
+        ## multi-threaded
+        if self.FFT_LIB_MT is None:
+            ## reuse FFT variables
+            self.variables.join('LIBFFT_MT', 'LIBFFT')
+        else:
+            self.variables.nappend('LIBFFT_MT', self.FFT_LIB_MT)
+            if getattr(self, 'LIB_MULTITHREAD', None) is not None:
+                self.variables.nappend('LIBFFT_MT', self.LIB_MULTITHREAD)
+
         self.variables.join('FFT_STATIC_LIBS', 'LIBFFT')
+        self.variables.join('FFT_STATIC_LIBS_MT', 'LIBFFT_MT')
+
         for root in self.get_software_root(self.FFT_MODULE_NAME):
             self.variables.append_exists('FFT_LIB_DIR', root, self.FFT_LIB_DIR)
             self.variables.append_exists('FFT_INC_DIR', root, self.FFT_INCLUDE_DIR)
