@@ -1,11 +1,11 @@
 # #
-# Copyright 2012-2014 Ghent University
+# Copyright 2012-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -25,10 +25,11 @@
 """
 Toolchain specific variables
 
-@author: Stijn De Weirdt (Ghent University)
-@author: Kenneth Hoste (Ghent University)
+:author: Stijn De Weirdt (Ghent University)
+:author: Kenneth Hoste (Ghent University)
 """
 
+from easybuild.tools.build_log import EasyBuildError
 from easybuild.tools.variables import StrList, AbsPathList
 
 
@@ -141,7 +142,7 @@ class LinkerFlagList(StrList):
                 else:
                     self.insert(idx, toggle_map[name])
             else:
-                self.log.raiseException("%s name %s not found in map %s" % (descr, name, toggle_map))
+                raise EasyBuildError("%s name %s not found in map %s", descr, name, toggle_map)
 
     def toggle_startgroup(self):
         """Append start group"""
