@@ -1,11 +1,11 @@
 # #
-# Copyright 2013-2014 Ghent University
+# Copyright 2013-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -28,24 +28,28 @@ Unit tests for easyconfig/parser.py
 @author: Stijn De Weirdt (Ghent University)
 """
 import os
-from test.framework.utilities import EnhancedTestCase
-from unittest import TestLoader, main
+import sys
+from test.framework.utilities import EnhancedTestCase, TestLoaderFiltered
+from unittest import TextTestRunner
 from vsc.utils.fancylogger import setLogLevelDebug, logToScreen
 
 import easybuild.tools.build_log
 from easybuild.framework.easyconfig.format.format import Dependency
+from easybuild.framework.easyconfig.format.pyheaderconfigobj import build_easyconfig_constants_dict
 from easybuild.framework.easyconfig.format.version import EasyVersion
 from easybuild.framework.easyconfig.parser import EasyConfigParser
+from easybuild.tools.build_log import EasyBuildError
+from easybuild.tools.filetools import read_file
 
 
-TESTDIRBASE = os.path.join(os.path.dirname(__file__), 'easyconfigs')
+TESTDIRBASE = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'easyconfigs')
 
 
 class EasyConfigParserTest(EnhancedTestCase):
     """Test the parser"""
 
     def test_v10(self):
-        ecp = EasyConfigParser(os.path.join(TESTDIRBASE, 'v1.0', 'GCC-4.6.3.eb'))
+        ecp = EasyConfigParser(os.path.join(TESTDIRBASE, 'v1.0', 'g', 'GCC', 'GCC-4.6.3.eb'))
 
         self.assertEqual(ecp._formatter.VERSION, EasyVersion('1.0'))
 
@@ -146,12 +150,62 @@ class EasyConfigParserTest(EnhancedTestCase):
         # restore
         easybuild.tools.build_log.EXPERIMENTAL = orig_experimental
 
+    def test_raw(self):
+        """Test passing of raw contents to EasyConfigParser."""
+        ec_file1 = os.path.join(TESTDIRBASE, 'v1.0', 'g', 'GCC', 'GCC-4.6.3.eb')
+        ec_txt1 = read_file(ec_file1)
+        ec_file2 = os.path.join(TESTDIRBASE, 'v1.0', 'g', 'gzip', 'gzip-1.5-goolf-1.4.10.eb')
+        ec_txt2 = read_file(ec_file2)
+
+        ecparser = EasyConfigParser(ec_file1)
+        self.assertEqual(ecparser.rawcontent, ec_txt1)
+
+        ecparser = EasyConfigParser(rawcontent=ec_txt2)
+        self.assertEqual(ecparser.rawcontent, ec_txt2)
+
+        # rawcontent supersedes passed filepath
+        ecparser = EasyConfigParser(ec_file1, rawcontent=ec_txt2)
+        self.assertEqual(ecparser.rawcontent, ec_txt2)
+        ec = ecparser.get_config_dict()
+        self.assertEqual(ec['name'], 'gzip')
+        self.assertEqual(ec['toolchain']['name'], 'goolf')
+
+        self.assertErrorRegex(EasyBuildError, "Neither filename nor rawcontent provided", EasyConfigParser)
+
+    def test_easyconfig_constants(self):
+        """Test available easyconfig constants."""
+        constants = build_easyconfig_constants_dict()
+        # make sure both keys and values are only strings
+        for constant_name in constants:
+            self.assertTrue(isinstance(constant_name, basestring), "Constant name %s is a string" % constant_name)
+            val = constants[constant_name]
+            self.assertTrue(isinstance(val, basestring), "Constant value %s is a string" % val)
+
+        # check a couple of randomly picked constant values
+        self.assertEqual(constants['SOURCE_TAR_GZ'], '%(name)s-%(version)s.tar.gz')
+        self.assertEqual(constants['PYPI_SOURCE'], 'https://pypi.python.org/packages/source/%(nameletter)s/%(name)s')
+        self.assertEqual(constants['GPLv2'], 'LicenseGPLv2')
+        self.assertEqual(constants['EXTERNAL_MODULE'], 'EXTERNAL_MODULE')
+
+    def test_check_value_types(self):
+        """Test checking of easyconfig parameter value types."""
+        test_ec = os.path.join(TESTDIRBASE, 'test_ecs', 'g', 'gzip', 'gzip-1.4-broken.eb')
+        error_msg_pattern = "Type checking of easyconfig parameter values failed: .*'version'.*"
+        ecp = EasyConfigParser(test_ec, auto_convert_value_types=False)
+        self.assertErrorRegex(EasyBuildError, error_msg_pattern, ecp.get_config_dict)
+
+        # test default behaviour: auto-converting of mismatched value types
+        ecp = EasyConfigParser(test_ec)
+        ecdict = ecp.get_config_dict()
+        self.assertEqual(ecdict['version'], '1.4')
+
+
 def suite():
     """ returns all the testcases in this module """
-    return TestLoader().loadTestsFromTestCase(EasyConfigParserTest)
+    return TestLoaderFiltered().loadTestsFromTestCase(EasyConfigParserTest, sys.argv[1:])
 
 
 if __name__ == '__main__':
     # logToScreen(enable=True)
     # setLogLevelDebug()
-    main()
+    TextTestRunner(verbosity=1).run(suite())
