@@ -1,11 +1,11 @@
 # #
-# Copyright 2013-2014 Ghent University
+# Copyright 2013-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -27,10 +27,12 @@ Unit tests for easyconfig/licenses.py
 
 @author: Stijn De Weirdt (Ghent University)
 """
-from test.framework.utilities import EnhancedTestCase
-from unittest import TestLoader, main
+import sys
 
-from easybuild.framework.easyconfig.licenses import License, VeryRestrictive, what_licenses
+from test.framework.utilities import EnhancedTestCase, TestLoaderFiltered
+from unittest import TextTestRunner
+
+from easybuild.framework.easyconfig.licenses import License, LicenseVeryRestrictive, what_licenses
 
 
 class LicenseTest(EnhancedTestCase):
@@ -39,9 +41,9 @@ class LicenseTest(EnhancedTestCase):
     def test_common_ones(self):
         """Check if a number of common licenses can be found"""
         lics = what_licenses()
-        commonlicenses = ['VeryRestrictive', 'GPLv2', 'GPLv3']
+        commonlicenses = ['LicenseVeryRestrictive', 'LicenseGPLv2', 'LicenseGPLv3']
         for lic in commonlicenses:
-            self.assertTrue(lic in lics)
+            self.assertTrue(lic in lics, "%s found in %s" % (lic, lics.keys()))
 
     def test_default_license(self):
         """Verify that the default License class is very restrictive"""
@@ -51,16 +53,25 @@ class LicenseTest(EnhancedTestCase):
 
     def test_veryrestrictive_license(self):
         """Verify that the very restrictive class is very restrictive"""
-        self.assertFalse(VeryRestrictive.DISTRIBUTE_SOURCE)
-        self.assertTrue(VeryRestrictive.GROUP_SOURCE)
-        self.assertTrue(VeryRestrictive.GROUP_BINARY)
+        self.assertFalse(LicenseVeryRestrictive.DISTRIBUTE_SOURCE)
+        self.assertTrue(LicenseVeryRestrictive.GROUP_SOURCE)
+        self.assertTrue(LicenseVeryRestrictive.GROUP_BINARY)
+
+    def test_licenses(self):
+        """Test format of available licenses."""
+        lics = what_licenses()
+        for lic in lics:
+            self.assertTrue(isinstance(lic, basestring))
+            self.assertTrue(lic.startswith('License'))
+            self.assertTrue(issubclass(lics[lic], License))
+
 
 def suite():
     """ returns all the testcases in this module """
-    return TestLoader().loadTestsFromTestCase(LicenseTest)
+    return TestLoaderFiltered().loadTestsFromTestCase(LicenseTest, sys.argv[1:])
 
 
 if __name__ == '__main__':
     # logToScreen(enable=True)
     # setLogLevelDebug()
-    main()
+    TextTestRunner(verbosity=1).run(suite())
