@@ -1,11 +1,11 @@
 # #
-# Copyright 2014-2014 Ghent University
+# Copyright 2014-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -29,19 +29,20 @@ Unit tests for ModulesTool class.
 """
 import os
 import re
+import stat
+import sys
 import tempfile
 from vsc.utils import fancylogger
 
-from test.framework.utilities import EnhancedTestCase
-from unittest import main as unittestmain
-from unittest import TestLoader
+from test.framework.utilities import EnhancedTestCase, TestLoaderFiltered
+from unittest import TextTestRunner
 from distutils.version import StrictVersion
 
 import easybuild.tools.options as eboptions
 from easybuild.tools import config, modules
 from easybuild.tools.build_log import EasyBuildError
 from easybuild.tools.config import build_option
-from easybuild.tools.filetools import which
+from easybuild.tools.filetools import which, write_file
 from easybuild.tools.modules import modules_tool, Lmod
 from test.framework.utilities import init_config
 
@@ -95,11 +96,11 @@ class ModulesToolTest(EnhancedTestCase):
             # should never get here
             self.assertTrue(False, 'BrokenMockModulesTool should fail')
         except EasyBuildError, err:
-            self.assertTrue('command is not available' in str(err))
+            err_msg = "command is not available"
+            self.assertTrue(err_msg in str(err), "'%s' found in: %s" % (err_msg, err))
 
         os.environ[BrokenMockModulesTool.COMMAND_ENVIRONMENT] = MockModulesTool.COMMAND
         os.environ['module'] = "() { /bin/echo $*\n}"
-        BrokenMockModulesTool._instances.pop(BrokenMockModulesTool, None)
         bmmt = BrokenMockModulesTool(mod_paths=[], testing=True)
         cmd_abspath = which(MockModulesTool.COMMAND)
 
@@ -133,13 +134,11 @@ class ModulesToolTest(EnhancedTestCase):
 
         # redefine 'module' function with correct module command
         os.environ['module'] = "() {  eval `/bin/echo $*`\n}"
-        MockModulesTool._instances.pop(MockModulesTool)
         mt = MockModulesTool(testing=True)
         self.assertTrue(isinstance(mt.loaded_modules(), list))  # dummy usage
 
         # a warning should be logged if the 'module' function is undefined
         del os.environ['module']
-        MockModulesTool._instances.pop(MockModulesTool)
         mt = MockModulesTool(testing=True)
         f = open(self.logfile, 'r')
         logtxt = f.read()
@@ -156,9 +155,13 @@ class ModulesToolTest(EnhancedTestCase):
         if lmod_abspath is not None:
             build_options = {
                 'allow_modules_tool_mismatch': True,
+                'update_modules_tool_cache': True,
             }
             init_config(build_options=build_options)
 
+            lmod = Lmod(testing=True)
+            self.assertTrue(os.path.samefile(lmod.cmd, lmod_abspath))
+
             # drop any location where 'lmod' or 'spider' can be found from $PATH
             paths = os.environ.get('PATH', '').split(os.pathsep)
             new_paths = []
@@ -172,8 +175,23 @@ class ModulesToolTest(EnhancedTestCase):
             # make sure $MODULEPATH contains path that provides some modules
             os.environ['MODULEPATH'] = os.path.abspath(os.path.join(os.path.dirname(__file__), 'modules'))
 
-            # initialize Lmod modules tool, pass full path to 'lmod' via $LMOD_CMD
+            # initialize Lmod modules tool, pass (fake) full path to 'lmod' via $LMOD_CMD
+            fake_path = os.path.join(self.test_installpath, 'lmod')
+            fake_lmod_txt = '\n'.join([
+                '#!/bin/bash',
+                'echo "Modules based on Lua: Version %s " >&2' % Lmod.REQ_VERSION,
+                'echo "os.environ[\'FOO\'] = \'foo\'"',
+            ])
+            write_file(fake_path, fake_lmod_txt)
+            os.chmod(fake_path, stat.S_IRUSR|stat.S_IXUSR)
+            os.environ['LMOD_CMD'] = fake_path
+            init_config(build_options=build_options)
+            lmod = Lmod(testing=True)
+            self.assertTrue(os.path.samefile(lmod.cmd, fake_path))
+
+            # use correct full path for 'lmod' via $LMOD_CMD
             os.environ['LMOD_CMD'] = lmod_abspath
+            init_config(build_options=build_options)
             lmod = Lmod(testing=True)
 
             # obtain list of availabe modules, should be non-empty
@@ -196,9 +214,9 @@ class ModulesToolTest(EnhancedTestCase):
 
 def suite():
     """ returns all the testcases in this module """
-    return TestLoader().loadTestsFromTestCase(ModulesToolTest)
+    return TestLoaderFiltered().loadTestsFromTestCase(ModulesToolTest, sys.argv[1:])
 
 
 if __name__ == '__main__':
-    unittestmain()
+    TextTestRunner(verbosity=1).run(suite())
 
