@@ -1,11 +1,11 @@
 ##
-# Copyright 2009-2014 Ghent University
+# Copyright 2009-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -38,9 +38,8 @@ class bar(EasyBlock):
     @staticmethod
     def extra_options():
         """Custom easyconfig parameters for bar."""
-
-        extra_vars = [
-                      ('bar_extra1', [None, "first bar-specific easyconfig parameter (mandatory)", MANDATORY]),
-                      ('bar_extra2', ['BAR', "second bar-specific easyconfig parameter", CUSTOM]),
-                     ]
+        extra_vars = {
+            'bar_extra1': [None, "first bar-specific easyconfig parameter (mandatory)", MANDATORY],
+            'bar_extra2': ['BAR', "second bar-specific easyconfig parameter", CUSTOM],
+        }
         return EasyBlock.extra_options(extra_vars)
