@@ -1,12 +1,12 @@
 #!/usr/bin/python
 # #
-# Copyright 2012-2014 Ghent University
+# Copyright 2012-2017 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
 # with support of Ghent University (http://ugent.be/hpc),
-# the Flemish Supercomputer Centre (VSC) (https://vscentrum.be/nl/en),
-# the Hercules foundation (http://www.herculesstichting.be/in_English)
+# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
+# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
 # and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
 #
 # http://github.com/hpcugent/easybuild
@@ -32,19 +32,29 @@ Usage: "python -m test.framework.suite" or "python test/framework/suite.py"
 """
 import glob
 import os
-import shutil
 import sys
 import tempfile
 import unittest
 from vsc.utils import fancylogger
 
+# initialize EasyBuild logging, so we disable it
+from easybuild.tools.build_log import EasyBuildError
+from easybuild.tools.options import set_tmpdir
+
+# set plain text key ring to be used, so a GitHub token stored in it can be obtained without having to provide a password
+try:
+    import keyring
+    keyring.set_keyring(keyring.backends.file.PlaintextKeyring())
+except (ImportError, AttributeError):
+    pass
+
 # disable all logging to significantly speed up tests
-import easybuild.tools.build_log  # initialize EasyBuild logging, so we disable it
 fancylogger.disableDefaultHandlers()
 fancylogger.setLogLevelError()
 
 # toolkit should be first to allow hacks to work
 import test.framework.asyncprocess as a
+import test.framework.build_log as bl
 import test.framework.config as c
 import test.framework.easyblock as b
 import test.framework.easyconfig as e
@@ -52,40 +62,41 @@ import test.framework.easyconfigparser as ep
 import test.framework.easyconfigformat as ef
 import test.framework.ebconfigobj as ebco
 import test.framework.easyconfigversion as ev
+import test.framework.environment as env
+import test.framework.docs as d
 import test.framework.filetools as f
 import test.framework.format_convert as f_c
+import test.framework.general as gen
 import test.framework.github as g
+import test.framework.include as i
 import test.framework.license as l
 import test.framework.module_generator as mg
 import test.framework.modules as m
 import test.framework.modulestool as mt
 import test.framework.options as o
 import test.framework.parallelbuild as p
+import test.framework.package as pkg
 import test.framework.repository as r
 import test.framework.robot as robot
 import test.framework.run as run
 import test.framework.scripts as sc
+import test.framework.style as st
 import test.framework.systemtools as s
 import test.framework.toolchain as tc
 import test.framework.toolchainvariables as tcv
 import test.framework.toy_build as t
+import test.framework.type_checking as et
 import test.framework.tweak as tw
 import test.framework.variables as v
+import test.framework.yeb as y
 
 
 # make sure temporary files can be created/used
-fd, fn = tempfile.mkstemp()
-os.close(fd)
-os.remove(fn)
-testdir = tempfile.mkdtemp()
-for test_fn in [fn, os.path.join(testdir, 'test')]:
-    try:
-        open(fn, 'w').write('test')
-    except IOError, err:
-        sys.stderr.write("ERROR: Can't write to temporary file %s, set $TMPDIR to a writeable directory (%s)" % (fn, err))
-        sys.exit(1)
-os.remove(fn)
-shutil.rmtree(testdir)
+try:
+    set_tmpdir(raise_error=True)
+except EasyBuildError, err:
+    sys.stderr.write("No execution rights on temporary files, specify another location via $TMPDIR: %s\n" % err)
+    sys.exit(1)
 
 # initialize logger for all the unit tests
 fd, log_fn = tempfile.mkstemp(prefix='easybuild-tests-', suffix='.log')
@@ -96,7 +107,8 @@ log = fancylogger.getLogger()
 
 # call suite() for each module and then run them all
 # note: make sure the options unit tests run first, to avoid running some of them with a readily initialized config
-tests = [o, r, ef, ev, ebco, ep, e, mg, m, mt, f, run, a, robot, b, v, g, tcv, tc, t, c, s, l, f_c, sc, tw]
+tests = [gen, bl, o, r, ef, ev, ebco, ep, e, mg, m, mt, f, run, a, robot, b, v, g, tcv, tc, t, c, s, l, f_c, sc,
+         tw, p, i, pkg, d, env, et, y, st]
 
 SUITE = unittest.TestSuite([x.suite() for x in tests])
 
